package Number::Phone::JP::AreaCode::Data::AreaCode2Address;

### AUTO GENERATED BY `generate_areacode2address.pl`
### *** DO NOT EDIT THIS FILE WITH MANUAL LABOR ***

use strict;
use warnings;
use utf8;

use parent qw/Exporter/;

our @EXPORT = qw/get_areacode2address_map/;

use constant AREACODE_TO_ADDRESS_MAP =>
{
  '11' => {
    'addresses' => [
      '北海道北広島市',
      '北海道札幌市',
      '北海道江別市',
      '北海道空知郡南幌町'
    ],
    'local_code_digits' => 3
  },
  '123' => {
    'addresses' => [
      '北海道千歳市',
      '北海道夕張市',
      '北海道夕張市富野',
      '北海道夕張郡',
      '北海道恵庭市'
    ],
    'local_code_digits' => 2
  },
  '124' => {
    'addresses' => [
      '北海道芦別市'
    ],
    'local_code_digits' => 2
  },
  '125' => {
    'addresses' => [
      '北海道樺戸郡新十津川町',
      '北海道樺戸郡浦臼町',
      '北海道歌志内市',
      '北海道滝川市',
      '北海道砂川市',
      '北海道空知郡上砂川町',
      '北海道空知郡奈井江町',
      '北海道赤平市',
      '北海道雨竜郡雨竜町'
    ],
    'local_code_digits' => 2
  },
  '126' => {
    'addresses' => [
      '北海道岩見沢市',
      '北海道樺戸郡月形町',
      '北海道石狩郡新篠津村',
      '北海道美唄市'
    ],
    'local_code_digits' => 2
  },
  '1267' => {
    'addresses' => [
      '北海道三笠市',
      '北海道岩見沢市宝水町'
    ],
    'local_code_digits' => 1
  },
  '133' => {
    'addresses' => [
      '北海道石狩市',
      '北海道石狩郡当別町'
    ],
    'local_code_digits' => 2
  },
  '134' => {
    'addresses' => [
      '北海道小樽市'
    ],
    'local_code_digits' => 2
  },
  '135' => {
    'addresses' => [
      '北海道余市郡',
      '北海道古宇郡',
      '北海道古平郡',
      '北海道岩内郡',
      '北海道積丹郡'
    ],
    'local_code_digits' => 2
  },
  '136' => {
    'addresses' => [
      '北海道寿都郡',
      '北海道島牧郡',
      '北海道磯谷郡',
      '北海道虻田郡ニセコ町',
      '北海道虻田郡京極町',
      '北海道虻田郡倶知安町',
      '北海道虻田郡喜茂別町',
      '北海道虻田郡留寿都村',
      '北海道虻田郡真狩村'
    ],
    'local_code_digits' => 2
  },
  '137' => {
    'addresses' => [
      '北海道久遠郡せたな町',
      '北海道二海郡八雲町',
      '北海道瀬棚郡'
    ],
    'local_code_digits' => 2
  },
  '1372' => {
    'addresses' => [
      '北海道茅部郡鹿部町'
    ],
    'local_code_digits' => 1
  },
  '1374' => {
    'addresses' => [
      '北海道茅部郡森町'
    ],
    'local_code_digits' => 1
  },
  '1377' => {
    'addresses' => [
      '北海道山越郡'
    ],
    'local_code_digits' => 1
  },
  '138' => {
    'addresses' => [
      '北海道亀田郡',
      '北海道函館市',
      '北海道北斗市'
    ],
    'local_code_digits' => 2
  },
  '139' => {
    'addresses' => [
      '北海道松前郡',
      '北海道檜山郡',
      '北海道爾志郡'
    ],
    'local_code_digits' => 2
  },
  '1392' => {
    'addresses' => [
      '北海道上磯郡'
    ],
    'local_code_digits' => 1
  },
  '1397' => {
    'addresses' => [
      '北海道奥尻郡'
    ],
    'local_code_digits' => 1
  },
  '1398' => {
    'addresses' => [
      '北海道久遠郡せたな町大成区',
      '北海道二海郡八雲町熊石大谷町',
      '北海道二海郡八雲町熊石平町',
      '北海道二海郡八雲町熊石折戸町',
      '北海道二海郡八雲町熊石根崎町',
      '北海道二海郡八雲町熊石泉岱町',
      '北海道二海郡八雲町熊石泊川町',
      '北海道二海郡八雲町熊石畳岩町',
      '北海道二海郡八雲町熊石相沼町',
      '北海道二海郡八雲町熊石西浜町',
      '北海道二海郡八雲町熊石見日町',
      '北海道二海郡八雲町熊石関内町',
      '北海道二海郡八雲町熊石雲石町',
      '北海道二海郡八雲町熊石館平町',
      '北海道二海郡八雲町熊石鮎川町',
      '北海道二海郡八雲町熊石鳴神町',
      '北海道二海郡八雲町熊石黒岩町'
    ],
    'local_code_digits' => 1
  },
  '142' => {
    'addresses' => [
      '北海道伊達市',
      '北海道有珠郡',
      '北海道虻田郡洞爺湖町',
      '北海道虻田郡豊浦町'
    ],
    'local_code_digits' => 2
  },
  '143' => {
    'addresses' => [
      '北海道室蘭市',
      '北海道登別市'
    ],
    'local_code_digits' => 2
  },
  '144' => {
    'addresses' => [
      '北海道白老郡',
      '北海道苫小牧市'
    ],
    'local_code_digits' => 2
  },
  '145' => {
    'addresses' => [
      '北海道勇払郡むかわ町',
      '北海道勇払郡厚真町',
      '北海道勇払郡安平町'
    ],
    'local_code_digits' => 2
  },
  '1456' => {
    'addresses' => [
      '北海道新冠郡新冠町里平',
      '北海道沙流郡日高町'
    ],
    'local_code_digits' => 1
  },
  '1457' => {
    'addresses' => [
      '北海道沙流郡平取町',
      '北海道沙流郡日高町三岩',
      '北海道沙流郡日高町千栄',
      '北海道沙流郡日高町宮下町',
      '北海道沙流郡日高町富岡',
      '北海道沙流郡日高町山手町',
      '北海道沙流郡日高町新町',
      '北海道沙流郡日高町日高',
      '北海道沙流郡日高町本町東',
      '北海道沙流郡日高町本町西',
      '北海道沙流郡日高町松風町',
      '北海道沙流郡日高町栄町東',
      '北海道沙流郡日高町栄町西',
      '北海道沙流郡日高町若葉町'
    ],
    'local_code_digits' => 1
  },
  '146' => {
    'addresses' => [
      '北海道新冠郡新冠町',
      '北海道日高郡新ひだか町',
      '北海道様似郡',
      '北海道浦河郡'
    ],
    'local_code_digits' => 2
  },
  '1466' => {
    'addresses' => [
      '北海道幌泉郡'
    ],
    'local_code_digits' => 1
  },
  '15' => {
    'addresses' => [
      '北海道中川郡池田町',
      '北海道中川郡豊頃町',
      '北海道十勝郡',
      '北海道川上郡'
    ],
    'local_code_digits' => 3
  },
  '152' => {
    'addresses' => [
      '北海道北見市常呂町',
      '北海道斜里郡',
      '北海道斜里郡小清水町',
      '北海道網走市',
      '北海道網走郡',
      '北海道網走郡大空町東藻琴',
      '北海道網走郡大空町東藻琴千草',
      '北海道網走郡大空町東藻琴大進',
      '北海道網走郡大空町東藻琴山園',
      '北海道網走郡大空町東藻琴新富',
      '北海道網走郡大空町東藻琴明生',
      '北海道網走郡大空町東藻琴末広',
      '北海道網走郡大空町東藻琴栄',
      '北海道網走郡大空町東藻琴清浦',
      '北海道網走郡大空町東藻琴福富',
      '北海道網走郡大空町東藻琴西倉'
    ],
    'local_code_digits' => 2
  },
  '153' => {
    'addresses' => [
      '北海道厚岸郡',
      '北海道根室市',
      '北海道標津郡中標津町',
      '北海道標津郡標津町',
      '北海道目梨郡',
      '北海道野付郡別海町',
      '北海道野付郡別海町尾岱沼',
      '北海道野付郡別海町尾岱沼岬町',
      '北海道野付郡別海町尾岱沼港町',
      '北海道野付郡別海町尾岱沼潮見町',
      '北海道野付郡別海町床丹'
    ],
    'local_code_digits' => 2
  },
  '154' => {
    'addresses' => [
      '北海道釧路市',
      '北海道釧路郡',
      '北海道阿寒郡'
    ],
    'local_code_digits' => 2
  },
  '1547' => {
    'addresses' => [
      '北海道白糠郡',
      '北海道釧路市音別町'
    ],
    'local_code_digits' => 1
  },
  '155' => {
    'addresses' => [
      '北海道中川郡幕別町',
      '北海道帯広市',
      '北海道河東郡音更町',
      '北海道河西郡'
    ],
    'local_code_digits' => 2
  },
  '1558' => {
    'addresses' => [
      '北海道中川郡幕別町忠類中当',
      '北海道中川郡幕別町忠類元忠類',
      '北海道中川郡幕別町忠類公親',
      '北海道中川郡幕別町忠類共栄',
      '北海道中川郡幕別町忠類協徳',
      '北海道中川郡幕別町忠類古里',
      '北海道中川郡幕別町忠類幌内',
      '北海道中川郡幕別町忠類幸町',
      '北海道中川郡幕別町忠類新生',
      '北海道中川郡幕別町忠類日和',
      '北海道中川郡幕別町忠類明和',
      '北海道中川郡幕別町忠類晩成',
      '北海道中川郡幕別町忠類朝日',
      '北海道中川郡幕別町忠類本町',
      '北海道中川郡幕別町忠類東宝',
      '北海道中川郡幕別町忠類栄町',
      '北海道中川郡幕別町忠類白銀町',
      '北海道中川郡幕別町忠類西当',
      '北海道中川郡幕別町忠類錦町',
      '北海道広尾郡'
    ],
    'local_code_digits' => 1
  },
  '156' => {
    'addresses' => [
      '北海道上川郡新得町',
      '北海道上川郡清水町',
      '北海道中川郡本別町',
      '北海道河東郡鹿追町',
      '北海道足寄郡'
    ],
    'local_code_digits' => 2
  },
  '1564' => {
    'addresses' => [
      '北海道河東郡上士幌町',
      '北海道河東郡士幌町'
    ],
    'local_code_digits' => 1
  },
  '157' => {
    'addresses' => [
      '北海道北見市',
      '北海道常呂郡置戸町',
      '北海道常呂郡訓子府町'
    ],
    'local_code_digits' => 2
  },
  '158' => {
    'addresses' => [
      '北海道紋別市',
      '北海道紋別郡滝上町',
      '北海道紋別郡興部町',
      '北海道紋別郡西興部村',
      '北海道紋別郡遠軽町',
      '北海道紋別郡雄武町'
    ],
    'local_code_digits' => 2
  },
  '1586' => {
    'addresses' => [
      '北海道紋別郡湧別町'
    ],
    'local_code_digits' => 1
  },
  '1587' => {
    'addresses' => [
      '北海道常呂郡佐呂間町'
    ],
    'local_code_digits' => 1
  },
  '162' => {
    'addresses' => [
      '北海道天塩郡豊富町',
      '北海道稚内市'
    ],
    'local_code_digits' => 2
  },
  '163' => {
    'addresses' => [
      '北海道利尻郡',
      '北海道枝幸郡枝幸町',
      '北海道礼文郡'
    ],
    'local_code_digits' => 2
  },
  '1632' => {
    'addresses' => [
      '北海道天塩郡天塩町',
      '北海道天塩郡幌延町',
      '北海道天塩郡遠別町'
    ],
    'local_code_digits' => 1
  },
  '1634' => {
    'addresses' => [
      '北海道枝幸郡中頓別町',
      '北海道枝幸郡浜頓別町'
    ],
    'local_code_digits' => 1
  },
  '1635' => {
    'addresses' => [
      '北海道宗谷郡'
    ],
    'local_code_digits' => 1
  },
  '164' => {
    'addresses' => [
      '北海道増毛郡',
      '北海道深川市',
      '北海道留萌市',
      '北海道留萌郡',
      '北海道苫前郡初山別村',
      '北海道苫前郡羽幌町',
      '北海道苫前郡苫前町',
      '北海道雨竜郡北竜町',
      '北海道雨竜郡妹背牛町',
      '北海道雨竜郡沼田町',
      '北海道雨竜郡秩父別町'
    ],
    'local_code_digits' => 2
  },
  '1648' => {
    'addresses' => [
      '北海道苫前郡羽幌町天売前浜',
      '北海道苫前郡羽幌町天売和浦',
      '北海道苫前郡羽幌町天売富磯',
      '北海道苫前郡羽幌町天売弁天',
      '北海道苫前郡羽幌町天売相影',
      '北海道苫前郡羽幌町焼尻東浜',
      '北海道苫前郡羽幌町焼尻白浜',
      '北海道苫前郡羽幌町焼尻緑ヶ丘',
      '北海道苫前郡羽幌町焼尻西浦'
    ],
    'local_code_digits' => 1
  },
  '165' => {
    'addresses' => [
      '北海道上川郡剣淵町',
      '北海道上川郡和寒町',
      '北海道士別市',
      '北海道雨竜郡幌加内町'
    ],
    'local_code_digits' => 2
  },
  '1654' => {
    'addresses' => [
      '北海道名寄市'
    ],
    'local_code_digits' => 1
  },
  '1655' => {
    'addresses' => [
      '北海道上川郡下川町',
      '北海道名寄市風連町'
    ],
    'local_code_digits' => 1
  },
  '1656' => {
    'addresses' => [
      '北海道中川郡中川町',
      '北海道中川郡美深町',
      '北海道中川郡音威子府村'
    ],
    'local_code_digits' => 1
  },
  '1658' => {
    'addresses' => [
      '北海道上川郡上川町',
      '北海道上川郡愛別町'
    ],
    'local_code_digits' => 1
  },
  '166' => {
    'addresses' => [
      '北海道上川郡当麻町',
      '北海道上川郡東川町',
      '北海道上川郡東神楽町',
      '北海道上川郡比布町',
      '北海道上川郡美瑛町',
      '北海道上川郡鷹栖町',
      '北海道旭川市'
    ],
    'local_code_digits' => 2
  },
  '167' => {
    'addresses' => [
      '北海道勇払郡占冠村',
      '北海道富良野市',
      '北海道空知郡上富良野町',
      '北海道空知郡中富良野町',
      '北海道空知郡南富良野町'
    ],
    'local_code_digits' => 2
  },
  '17' => {
    'addresses' => [
      '青森県東津軽郡平内町',
      '青森県青森市'
    ],
    'local_code_digits' => 3
  },
  '172' => {
    'addresses' => [
      '青森県中津軽郡',
      '青森県北津軽郡板柳町',
      '青森県南津軽郡',
      '青森県平川市',
      '青森県弘前市',
      '青森県青森市浪岡',
      '青森県黒石市'
    ],
    'local_code_digits' => 2
  },
  '173' => {
    'addresses' => [
      '青森県つがる市',
      '青森県五所川原市',
      '青森県北津軽郡中泊町',
      '青森県北津軽郡鶴田町',
      '青森県西津軽郡'
    ],
    'local_code_digits' => 2
  },
  '174' => {
    'addresses' => [
      '青森県東津軽郡今別町',
      '青森県東津軽郡外ヶ浜町',
      '青森県東津軽郡蓬田村'
    ],
    'local_code_digits' => 2
  },
  '175' => {
    'addresses' => [
      '青森県むつ市',
      '青森県上北郡六ヶ所村',
      '青森県上北郡東北町',
      '青森県上北郡横浜町',
      '青森県上北郡野辺地町',
      '青森県下北郡'
    ],
    'local_code_digits' => 2
  },
  '176' => {
    'addresses' => [
      '青森県三沢市',
      '青森県上北郡七戸町',
      '青森県上北郡六戸町',
      '青森県上北郡東北町上北北',
      '青森県上北郡東北町上北南',
      '青森県上北郡東北町上野',
      '青森県上北郡東北町大浦',
      '青森県上北郡東北町新館',
      '青森県上北郡東北町旭北',
      '青森県上北郡東北町旭南',
      '青森県十和田市'
    ],
    'local_code_digits' => 2
  },
  '178' => {
    'addresses' => [
      '青森県三戸郡五戸町',
      '青森県三戸郡南部町',
      '青森県三戸郡新郷村',
      '青森県三戸郡階上町',
      '青森県上北郡おいらせ町',
      '青森県八戸市'
    ],
    'local_code_digits' => 2
  },
  '179' => {
    'addresses' => [
      '青森県三戸郡三戸町',
      '青森県三戸郡南部町大向',
      '青森県三戸郡南部町小向',
      '青森県三戸郡南部町沖田面',
      '青森県三戸郡南部町玉掛',
      '青森県三戸郡南部町相内',
      '青森県三戸郡南部町赤石',
      '青森県三戸郡田子町'
    ],
    'local_code_digits' => 2
  },
  '18' => {
    'addresses' => [
      '秋田県南秋田郡五城目町',
      '秋田県南秋田郡井川町',
      '秋田県南秋田郡八郎潟町',
      '秋田県大仙市協和上淀川',
      '秋田県大仙市協和下淀川',
      '秋田県大仙市協和中淀川',
      '秋田県大仙市協和境',
      '秋田県大仙市協和小種',
      '秋田県大仙市協和峰吉川',
      '秋田県大仙市協和稲沢',
      '秋田県大仙市協和船岡',
      '秋田県大仙市協和船沢',
      '秋田県大仙市協和荒川',
      '秋田県潟上市',
      '秋田県秋田市'
    ],
    'local_code_digits' => 3
  },
  '182' => {
    'addresses' => [
      '秋田県仙北郡美郷町野荒町',
      '秋田県仙北郡美郷町金沢',
      '秋田県横手市',
      '秋田県雄勝郡東成瀬村'
    ],
    'local_code_digits' => 2
  },
  '183' => {
    'addresses' => [
      '秋田県湯沢市',
      '秋田県雄勝郡羽後町'
    ],
    'local_code_digits' => 2
  },
  '184' => {
    'addresses' => [
      '秋田県にかほ市',
      '秋田県由利本荘市'
    ],
    'local_code_digits' => 2
  },
  '185' => {
    'addresses' => [
      '秋田県南秋田郡大潟村',
      '秋田県山本郡',
      '秋田県男鹿市',
      '秋田県能代市'
    ],
    'local_code_digits' => 2
  },
  '186' => {
    'addresses' => [
      '秋田県北秋田市',
      '秋田県北秋田郡',
      '秋田県大館市',
      '秋田県鹿角市',
      '秋田県鹿角郡小坂町'
    ],
    'local_code_digits' => 2
  },
  '187' => {
    'addresses' => [
      '秋田県仙北市',
      '秋田県仙北郡美郷町',
      '秋田県大仙市',
      '秋田県大仙市上鶯野',
      '秋田県大仙市下鶯野',
      '秋田県大仙市北長野',
      '秋田県大仙市大神成',
      '秋田県大仙市栗沢',
      '秋田県大仙市清水',
      '秋田県大仙市豊岡',
      '秋田県大仙市豊川',
      '秋田県大仙市鑓見内',
      '秋田県大仙市長戸呂',
      '秋田県大仙市長野'
    ],
    'local_code_digits' => 2
  },
  '19' => {
    'addresses' => [
      '岩手県岩手郡滝沢村',
      '岩手県岩手郡雫石町',
      '岩手県盛岡市',
      '岩手県紫波郡'
    ],
    'local_code_digits' => 3
  },
  '191' => {
    'addresses' => [
      '岩手県一関市',
      '岩手県西磐井郡'
    ],
    'local_code_digits' => 2
  },
  '192' => {
    'addresses' => [
      '岩手県大船渡市',
      '岩手県気仙郡',
      '岩手県陸前高田市'
    ],
    'local_code_digits' => 2
  },
  '193' => {
    'addresses' => [
      '岩手県上閉伊郡',
      '岩手県下閉伊郡山田町',
      '岩手県宮古市',
      '岩手県釜石市'
    ],
    'local_code_digits' => 2
  },
  '194' => {
    'addresses' => [
      '岩手県下閉伊郡',
      '岩手県久慈市',
      '岩手県九戸郡洋野町',
      '岩手県九戸郡野田村'
    ],
    'local_code_digits' => 2
  },
  '195' => {
    'addresses' => [
      '岩手県九戸郡九戸村',
      '岩手県九戸郡軽米町',
      '岩手県二戸市',
      '岩手県二戸郡',
      '岩手県八幡平市',
      '岩手県岩手郡岩手町',
      '岩手県岩手郡葛巻町'
    ],
    'local_code_digits' => 2
  },
  '197' => {
    'addresses' => [
      '岩手県北上市',
      '岩手県和賀郡',
      '岩手県奥州市',
      '岩手県胆沢郡'
    ],
    'local_code_digits' => 2
  },
  '198' => {
    'addresses' => [
      '岩手県花巻市',
      '岩手県遠野市'
    ],
    'local_code_digits' => 2
  },
  '22' => {
    'addresses' => [
      '宮城県仙台市',
      '宮城県名取市',
      '宮城県塩竈市',
      '宮城県多賀城市',
      '宮城県宮城郡',
      '宮城県黒川郡'
    ],
    'local_code_digits' => 3
  },
  '220' => {
    'addresses' => [
      '宮城県登米市'
    ],
    'local_code_digits' => 2
  },
  '223' => {
    'addresses' => [
      '宮城県亘理郡',
      '宮城県名取市堀内',
      '宮城県岩沼市'
    ],
    'local_code_digits' => 2
  },
  '224' => {
    'addresses' => [
      '宮城県伊具郡',
      '宮城県刈田郡',
      '宮城県柴田郡',
      '宮城県白石市',
      '宮城県角田市'
    ],
    'local_code_digits' => 2
  },
  '225' => {
    'addresses' => [
      '宮城県東松島市',
      '宮城県牡鹿郡',
      '宮城県登米市津山町',
      '宮城県登米市豊里町',
      '宮城県石巻市'
    ],
    'local_code_digits' => 2
  },
  '226' => {
    'addresses' => [
      '宮城県本吉郡',
      '宮城県気仙沼市'
    ],
    'local_code_digits' => 2
  },
  '228' => {
    'addresses' => [
      '宮城県栗原市',
      '宮城県登米市石越町'
    ],
    'local_code_digits' => 2
  },
  '229' => {
    'addresses' => [
      '宮城県加美郡',
      '宮城県大崎市',
      '宮城県遠田郡'
    ],
    'local_code_digits' => 2
  },
  '23' => {
    'addresses' => [
      '山形県上山市',
      '山形県天童市',
      '山形県山形市',
      '山形県東村山郡'
    ],
    'local_code_digits' => 3
  },
  '233' => {
    'addresses' => [
      '山形県新庄市',
      '山形県最上郡'
    ],
    'local_code_digits' => 2
  },
  '234' => {
    'addresses' => [
      '山形県東田川郡庄内町',
      '山形県酒田市',
      '山形県飽海郡'
    ],
    'local_code_digits' => 2
  },
  '235' => {
    'addresses' => [
      '山形県東田川郡三川町',
      '山形県鶴岡市'
    ],
    'local_code_digits' => 2
  },
  '237' => {
    'addresses' => [
      '山形県北村山郡',
      '山形県寒河江市',
      '山形県尾花沢市',
      '山形県村山市',
      '山形県東根市',
      '山形県西村山郡'
    ],
    'local_code_digits' => 2
  },
  '238' => {
    'addresses' => [
      '山形県南陽市',
      '山形県東置賜郡',
      '山形県米沢市',
      '山形県西置賜郡',
      '山形県長井市'
    ],
    'local_code_digits' => 2
  },
  '24' => {
    'addresses' => [
      '福島県伊達市',
      '福島県伊達郡',
      '福島県田村郡三春町上舞木',
      '福島県田村郡三春町下舞木',
      '福島県田村郡三春町斎藤',
      '福島県田村郡三春町沼沢',
      '福島県福島市',
      '福島県郡山市'
    ],
    'local_code_digits' => 3
  },
  '240' => {
    'addresses' => [
      '福島県双葉郡'
    ],
    'local_code_digits' => 2
  },
  '241' => {
    'addresses' => [
      '福島県南会津郡下郷町',
      '福島県南会津郡南会津町',
      '福島県南会津郡南会津町中荒井',
      '福島県南会津郡南会津町丹藤',
      '福島県南会津郡南会津町塩江',
      '福島県南会津郡南会津町川島',
      '福島県南会津郡南会津町栗生沢',
      '福島県南会津郡南会津町水無',
      '福島県南会津郡南会津町永田',
      '福島県南会津郡南会津町滝原',
      '福島県南会津郡南会津町田島',
      '福島県南会津郡南会津町田部',
      '福島県南会津郡南会津町福米沢',
      '福島県南会津郡南会津町糸沢',
      '福島県南会津郡南会津町藤生',
      '福島県南会津郡南会津町金井沢',
      '福島県南会津郡南会津町針生',
      '福島県南会津郡南会津町長野',
      '福島県南会津郡南会津町関本',
      '福島県南会津郡南会津町静川',
      '福島県南会津郡南会津町高野',
      '福島県南会津郡只見町',
      '福島県南会津郡檜枝岐村',
      '福島県喜多方市',
      '福島県喜多方市高郷町',
      '福島県大沼郡三島町',
      '福島県大沼郡昭和村',
      '福島県大沼郡金山町',
      '福島県河沼郡柳津町',
      '福島県河沼郡湯川村',
      '福島県耶麻郡北塩原村',
      '福島県耶麻郡西会津町'
    ],
    'local_code_digits' => 2
  },
  '242' => {
    'addresses' => [
      '福島県会津若松市',
      '福島県大沼郡会津美里町',
      '福島県河沼郡会津坂下町',
      '福島県耶麻郡猪苗代町',
      '福島県耶麻郡磐梯町'
    ],
    'local_code_digits' => 2
  },
  '243' => {
    'addresses' => [
      '福島県二本松市',
      '福島県安達郡',
      '福島県本宮市'
    ],
    'local_code_digits' => 2
  },
  '244' => {
    'addresses' => [
      '福島県南相馬市',
      '福島県相馬市',
      '福島県相馬郡'
    ],
    'local_code_digits' => 2
  },
  '246' => {
    'addresses' => [
      '福島県いわき市'
    ],
    'local_code_digits' => 2
  },
  '247' => {
    'addresses' => [
      '福島県東白川郡',
      '福島県田村市',
      '福島県田村郡',
      '福島県石川郡'
    ],
    'local_code_digits' => 2
  },
  '248' => {
    'addresses' => [
      '福島県岩瀬郡',
      '福島県白河市',
      '福島県西白河郡',
      '福島県須賀川市'
    ],
    'local_code_digits' => 2
  },
  '25' => {
    'addresses' => [
      '新潟県上越市',
      '新潟県上越市大島区',
      '新潟県上越市安塚区',
      '新潟県上越市浦川原区',
      '新潟県中魚沼郡',
      '新潟県北蒲原郡聖籠町亀塚',
      '新潟県北蒲原郡聖籠町位守町',
      '新潟県北蒲原郡聖籠町別條',
      '新潟県北蒲原郡聖籠町東港',
      '新潟県十日町市',
      '新潟県十日町市中子',
      '新潟県十日町市仙納',
      '新潟県十日町市会沢',
      '新潟県十日町市儀明',
      '新潟県十日町市千年',
      '新潟県十日町市名平',
      '新潟県十日町市太平',
      '新潟県十日町市奈良立',
      '新潟県十日町市孟地',
      '新潟県十日町市室野',
      '新潟県十日町市寺田',
      '新潟県十日町市小屋丸',
      '新潟県十日町市小池',
      '新潟県十日町市小荒戸',
      '新潟県十日町市峠',
      '新潟県十日町市木和田原',
      '新潟県十日町市松之山',
      '新潟県十日町市松之山三桶',
      '新潟県十日町市松之山上鰕池',
      '新潟県十日町市松之山下鰕池',
      '新潟県十日町市松之山中尾',
      '新潟県十日町市松之山五十子平',
      '新潟県十日町市松之山光間',
      '新潟県十日町市松之山古戸',
      '新潟県十日町市松之山坂下',
      '新潟県十日町市松之山坪野',
      '新潟県十日町市松之山大荒戸',
      '新潟県十日町市松之山天水島',
      '新潟県十日町市松之山天水越',
      '新潟県十日町市松之山小谷',
      '新潟県十日町市松之山新山',
      '新潟県十日町市松之山東山',
      '新潟県十日町市松之山東川',
      '新潟県十日町市松之山松口',
      '新潟県十日町市松之山橋詰',
      '新潟県十日町市松之山水梨',
      '新潟県十日町市松之山沢口',
      '新潟県十日町市松之山湯山',
      '新潟県十日町市松之山湯本',
      '新潟県十日町市松之山猪之名',
      '新潟県十日町市松之山藤倉',
      '新潟県十日町市松之山藤内名',
      '新潟県十日町市松之山観音寺',
      '新潟県十日町市松之山赤倉',
      '新潟県十日町市松之山黒倉',
      '新潟県十日町市松代',
      '新潟県十日町市松代下山',
      '新潟県十日町市松代東山',
      '新潟県十日町市松代田沢',
      '新潟県十日町市松山新田',
      '新潟県十日町市桐山',
      '新潟県十日町市池之畑',
      '新潟県十日町市池尻',
      '新潟県十日町市浦田',
      '新潟県十日町市海老',
      '新潟県十日町市清水',
      '新潟県十日町市滝沢',
      '新潟県十日町市片桐山',
      '新潟県十日町市犬伏',
      '新潟県十日町市田野倉',
      '新潟県十日町市福島',
      '新潟県十日町市苧島',
      '新潟県十日町市荒瀬',
      '新潟県十日町市莇平',
      '新潟県十日町市菅刈',
      '新潟県十日町市蒲生',
      '新潟県十日町市蓬平',
      '新潟県南魚沼市',
      '新潟県南魚沼郡',
      '新潟県新潟市中央区',
      '新潟県新潟市北区',
      '新潟県新潟市南区',
      '新潟県新潟市東区',
      '新潟県新潟市江南区',
      '新潟県新潟市秋葉区覚路津',
      '新潟県新潟市西区',
      '新潟県新潟市西蒲区三ツ門',
      '新潟県新潟市西蒲区上小吉',
      '新潟県新潟市西蒲区中之口',
      '新潟県新潟市西蒲区五之上',
      '新潟県新潟市西蒲区六部',
      '新潟県新潟市西蒲区姥島',
      '新潟県新潟市西蒲区小吉',
      '新潟県新潟市西蒲区巻大原',
      '新潟県新潟市西蒲区打越',
      '新潟県新潟市西蒲区東中',
      '新潟県新潟市西蒲区東小吉',
      '新潟県新潟市西蒲区東船越',
      '新潟県新潟市西蒲区河間',
      '新潟県新潟市西蒲区潟浦新',
      '新潟県新潟市西蒲区牧ケ島',
      '新潟県新潟市西蒲区真木',
      '新潟県新潟市西蒲区福島',
      '新潟県新潟市西蒲区羽黒',
      '新潟県新潟市西蒲区道上',
      '新潟県新潟市西蒲区針ヶ曽根',
      '新潟県新潟市西蒲区長場',
      '新潟県新潟市西蒲区門田',
      '新潟県新潟市西蒲区高野宮',
      '新潟県糸魚川市',
      '新潟県魚沼市'
    ],
    'local_code_digits' => 3
  },
  '250' => {
    'addresses' => [
      '新潟県五泉市',
      '新潟県新潟市秋葉区',
      '新潟県阿賀野市'
    ],
    'local_code_digits' => 2
  },
  '254' => {
    'addresses' => [
      '新潟県北蒲原郡聖籠町',
      '新潟県岩船郡',
      '新潟県新発田市',
      '新潟県村上市',
      '新潟県東蒲原郡',
      '新潟県胎内市'
    ],
    'local_code_digits' => 2
  },
  '255' => {
    'addresses' => [
      '新潟県上越市中郷区',
      '新潟県上越市板倉区',
      '新潟県妙高市'
    ],
    'local_code_digits' => 2
  },
  '256' => {
    'addresses' => [
      '新潟県三条市',
      '新潟県加茂市',
      '新潟県南蒲原郡',
      '新潟県新潟市西蒲区',
      '新潟県燕市',
      '新潟県燕市三王渕',
      '新潟県燕市上児木',
      '新潟県燕市下児木',
      '新潟県燕市中川',
      '新潟県燕市二階堂',
      '新潟県燕市井土巻',
      '新潟県燕市佐渡',
      '新潟県燕市八王寺',
      '新潟県燕市勘新',
      '新潟県燕市南',
      '新潟県燕市又新',
      '新潟県燕市四ツ屋',
      '新潟県燕市大曲',
      '新潟県燕市大船渡',
      '新潟県燕市大関',
      '新潟県燕市小中川',
      '新潟県燕市小古津新',
      '新潟県燕市小池',
      '新潟県燕市小池新町',
      '新潟県燕市小牧',
      '新潟県燕市小関',
      '新潟県燕市小高',
      '新潟県燕市新栄町',
      '新潟県燕市新生町',
      '新潟県燕市日之出町',
      '新潟県燕市杉名',
      '新潟県燕市杉柳',
      '新潟県燕市杣木',
      '新潟県燕市東太田',
      '新潟県燕市松橋',
      '新潟県燕市柳山',
      '新潟県燕市桜町',
      '新潟県燕市横田',
      '新潟県燕市次新',
      '新潟県燕市殿島',
      '新潟県燕市水道町',
      '新潟県燕市灰方',
      '新潟県燕市燕',
      '新潟県燕市物流センタ－',
      '新潟県燕市白山町',
      '新潟県燕市秋葉町',
      '新潟県燕市舘野',
      '新潟県燕市花園町',
      '新潟県燕市花見',
      '新潟県燕市蔵関',
      '新潟県燕市道金',
      '新潟県燕市長所',
      '新潟県燕市長所乙',
      '新潟県燕市長所甲',
      '新潟県燕市長渡',
      '新潟県燕市関崎',
      '新潟県西蒲原郡',
      '新潟県長岡市下沼新田',
      '新潟県長岡市中之島西野',
      '新潟県長岡市中条新田',
      '新潟県長岡市大沼新田',
      '新潟県長岡市寺泊万善寺',
      '新潟県長岡市寺泊下中条',
      '新潟県長岡市寺泊下桐',
      '新潟県長岡市寺泊中曽根',
      '新潟県長岡市寺泊五分一',
      '新潟県長岡市寺泊入軽井',
      '新潟県長岡市寺泊北曽根',
      '新潟県長岡市寺泊小豆曽根',
      '新潟県長岡市寺泊岩方',
      '新潟県長岡市寺泊平野新村新田',
      '新潟県長岡市寺泊当新田',
      '新潟県長岡市寺泊敦ケ曽根',
      '新潟県長岡市寺泊新長',
      '新潟県長岡市寺泊有信',
      '新潟県長岡市寺泊木島',
      '新潟県長岡市寺泊求草',
      '新潟県長岡市寺泊田尻',
      '新潟県長岡市寺泊町軽井',
      '新潟県長岡市寺泊矢田',
      '新潟県長岡市寺泊硲田',
      '新潟県長岡市寺泊竹森',
      '新潟県長岡市寺泊蛇塚',
      '新潟県長岡市寺泊高内',
      '新潟県長岡市寺泊鰐口',
      '新潟県長岡市小沼新田',
      '新潟県長岡市真野代新田',
      '新潟県長岡市赤沼'
    ],
    'local_code_digits' => 2
  },
  '257' => {
    'addresses' => [
      '新潟県刈羽郡',
      '新潟県柏崎市'
    ],
    'local_code_digits' => 2
  },
  '258' => {
    'addresses' => [
      '新潟県三島郡',
      '新潟県小千谷市',
      '新潟県見附市',
      '新潟県長岡市'
    ],
    'local_code_digits' => 2
  },
  '259' => {
    'addresses' => [
      '新潟県佐渡市'
    ],
    'local_code_digits' => 2
  },
  '26' => {
    'addresses' => [
      '長野県上水内郡',
      '長野県上高井郡',
      '長野県千曲市',
      '長野県長野市',
      '長野県須坂市'
    ],
    'local_code_digits' => 3
  },
  '260' => {
    'addresses' => [
      '長野県下伊那郡下條村',
      '長野県下伊那郡売木村',
      '長野県下伊那郡天龍村',
      '長野県下伊那郡泰阜村',
      '長野県下伊那郡阿南町',
      '長野県飯田市上村',
      '長野県飯田市南信濃八重河内',
      '長野県飯田市南信濃南和田',
      '長野県飯田市南信濃和田',
      '長野県飯田市南信濃木沢'
    ],
    'local_code_digits' => 2
  },
  '261' => {
    'addresses' => [
      '長野県北安曇郡',
      '長野県大町市'
    ],
    'local_code_digits' => 2
  },
  '263' => {
    'addresses' => [
      '長野県塩尻市',
      '長野県安曇野市',
      '長野県東筑摩郡',
      '長野県松本市'
    ],
    'local_code_digits' => 2
  },
  '264' => {
    'addresses' => [
      '長野県塩尻市奈良井',
      '長野県塩尻市木曽平沢',
      '長野県塩尻市贄川',
      '長野県木曽郡'
    ],
    'local_code_digits' => 2
  },
  '265' => {
    'addresses' => [
      '長野県上伊那郡',
      '長野県下伊那郡',
      '長野県伊那市',
      '長野県飯田市',
      '長野県駒ヶ根市'
    ],
    'local_code_digits' => 2
  },
  '266' => {
    'addresses' => [
      '長野県上伊那郡辰野町',
      '長野県岡谷市',
      '長野県茅野市',
      '長野県諏訪市',
      '長野県諏訪郡'
    ],
    'local_code_digits' => 2
  },
  '267' => {
    'addresses' => [
      '長野県佐久市',
      '長野県北佐久郡',
      '長野県北佐久郡立科町',
      '長野県南佐久郡',
      '長野県小諸市'
    ],
    'local_code_digits' => 2
  },
  '268' => {
    'addresses' => [
      '長野県上田市',
      '長野県埴科郡',
      '長野県小県郡',
      '長野県東御市'
    ],
    'local_code_digits' => 2
  },
  '269' => {
    'addresses' => [
      '長野県下水内郡',
      '長野県下高井郡山之内町',
      '長野県下高井郡木島平村',
      '長野県下高井郡野沢温泉村',
      '長野県中野市',
      '長野県飯山市'
    ],
    'local_code_digits' => 2
  },
  '27' => {
    'addresses' => [
      '群馬県前橋市',
      '群馬県安中市',
      '群馬県高崎市'
    ],
    'local_code_digits' => 3
  },
  '270' => {
    'addresses' => [
      '群馬県伊勢崎市',
      '群馬県佐波郡'
    ],
    'local_code_digits' => 2
  },
  '274' => {
    'addresses' => [
      '埼玉県児玉郡神川町上阿久原',
      '埼玉県児玉郡神川町下阿久原',
      '埼玉県児玉郡神川町渡瀬',
      '埼玉県児玉郡神川町矢納',
      '群馬県多野郡',
      '群馬県富岡市',
      '群馬県甘楽郡',
      '群馬県藤岡市',
      '群馬県高崎市新町'
    ],
    'local_code_digits' => 2
  },
  '276' => {
    'addresses' => [
      '埼玉県熊谷市妻沼小島',
      '群馬県太田市',
      '群馬県邑楽郡',
      '群馬県館林市'
    ],
    'local_code_digits' => 2
  },
  '277' => {
    'addresses' => [
      '群馬県みどり市',
      '群馬県太田市六千石町',
      '群馬県太田市大久保町',
      '群馬県太田市大原町',
      '群馬県太田市寄合町',
      '群馬県太田市山之神町',
      '群馬県太田市藪塚町',
      '群馬県桐生市'
    ],
    'local_code_digits' => 2
  },
  '278' => {
    'addresses' => [
      '群馬県利根郡',
      '群馬県沼田市'
    ],
    'local_code_digits' => 2
  },
  '279' => {
    'addresses' => [
      '群馬県北群馬郡',
      '群馬県吾妻郡',
      '群馬県吾妻郡中之条町',
      '群馬県吾妻郡中之条町入山',
      '群馬県吾妻郡中之条町太子',
      '群馬県吾妻郡中之条町小雨',
      '群馬県吾妻郡中之条町日影',
      '群馬県吾妻郡中之条町生須',
      '群馬県吾妻郡中之条町赤岩',
      '群馬県吾妻郡東吾妻町',
      '群馬県吾妻郡高山村',
      '群馬県渋川市'
    ],
    'local_code_digits' => 2
  },
  '28' => {
    'addresses' => [
      '栃木県さくら市',
      '栃木県塩谷郡高根沢町',
      '栃木県宇都宮市',
      '栃木県芳賀郡芳賀町'
    ],
    'local_code_digits' => 3
  },
  '280' => {
    'addresses' => [
      '埼玉県加須市伊賀袋',
      '埼玉県加須市向古河',
      '埼玉県加須市小野袋',
      '埼玉県加須市本郷',
      '埼玉県加須市柏戸',
      '埼玉県加須市柳生',
      '埼玉県加須市栄',
      '埼玉県加須市陽光台',
      '埼玉県加須市飯積',
      '埼玉県加須市駒場',
      '埼玉県加須市麦倉',
      '栃木県下都賀郡野木町',
      '栃木県小山市下生井',
      '茨城県古河市',
      '茨城県坂東市山',
      '茨城県坂東市生子',
      '茨城県坂東市生子新田',
      '茨城県坂東市菅谷',
      '茨城県坂東市逆井',
      '茨城県猿島郡'
    ],
    'local_code_digits' => 2
  },
  '282' => {
    'addresses' => [
      '栃木県下都賀郡',
      '栃木県小山市上生井',
      '栃木県小山市白鳥',
      '栃木県栃木市'
    ],
    'local_code_digits' => 2
  },
  '283' => {
    'addresses' => [
      '栃木県佐野市'
    ],
    'local_code_digits' => 2
  },
  '284' => {
    'addresses' => [
      '栃木県足利市',
      '群馬県太田市市場町'
    ],
    'local_code_digits' => 2
  },
  '285' => {
    'addresses' => [
      '栃木県下野市',
      '栃木県小山市',
      '栃木県河内郡',
      '栃木県真岡市',
      '栃木県芳賀郡'
    ],
    'local_code_digits' => 2
  },
  '287' => {
    'addresses' => [
      '栃木県塩谷郡塩谷町',
      '栃木県大田原市',
      '栃木県矢板市',
      '栃木県那須塩原市',
      '栃木県那須塩原市あたご町',
      '栃木県那須塩原市一区町',
      '栃木県那須塩原市三区町',
      '栃木県那須塩原市三島',
      '栃木県那須塩原市上塩原',
      '栃木県那須塩原市上大貫',
      '栃木県那須塩原市上横林',
      '栃木県那須塩原市上赤田',
      '栃木県那須塩原市下大貫',
      '栃木県那須塩原市下永田',
      '栃木県那須塩原市下田野',
      '栃木県那須塩原市中塩原',
      '栃木県那須塩原市二つ室',
      '栃木県那須塩原市二区町',
      '栃木県那須塩原市五軒町',
      '栃木県那須塩原市井口',
      '栃木県那須塩原市北二つ室',
      '栃木県那須塩原市北赤田',
      '栃木県那須塩原市千本松',
      '栃木県那須塩原市南町',
      '栃木県那須塩原市南赤田',
      '栃木県那須塩原市南郷屋',
      '栃木県那須塩原市四区町',
      '栃木県那須塩原市塩原',
      '栃木県那須塩原市太夫塚',
      '栃木県那須塩原市宇都野',
      '栃木県那須塩原市扇町',
      '栃木県那須塩原市折戸',
      '栃木県那須塩原市接骨木',
      '栃木県那須塩原市新南',
      '栃木県那須塩原市東三島',
      '栃木県那須塩原市東町',
      '栃木県那須塩原市東赤田',
      '栃木県那須塩原市東遅沢',
      '栃木県那須塩原市東関根',
      '栃木県那須塩原市槻沢',
      '栃木県那須塩原市横林',
      '栃木県那須塩原市永田町',
      '栃木県那須塩原市湯本塩原',
      '栃木県那須塩原市睦',
      '栃木県那須塩原市石林',
      '栃木県那須塩原市笹沼',
      '栃木県那須塩原市緑',
      '栃木県那須塩原市蟇沼',
      '栃木県那須塩原市西三島',
      '栃木県那須塩原市西原町',
      '栃木県那須塩原市西大和',
      '栃木県那須塩原市西富山',
      '栃木県那須塩原市西幸町',
      '栃木県那須塩原市西朝日町',
      '栃木県那須塩原市西栄町',
      '栃木県那須塩原市西赤田',
      '栃木県那須塩原市西遅沢',
      '栃木県那須塩原市遅野沢',
      '栃木県那須塩原市金沢',
      '栃木県那須塩原市関根',
      '栃木県那須塩原市関谷',
      '栃木県那須塩原市高柳',
      '栃木県那須塩原市高阿津',
      '栃木県那須烏山市',
      '栃木県那須郡那珂川町',
      '栃木県那須郡那須町'
    ],
    'local_code_digits' => 2
  },
  '288' => {
    'addresses' => [
      '栃木県日光市'
    ],
    'local_code_digits' => 2
  },
  '289' => {
    'addresses' => [
      '栃木県鹿沼市'
    ],
    'local_code_digits' => 2
  },
  '29' => {
    'addresses' => [
      '茨城県かすみがうら市一の瀬',
      '茨城県かすみがうら市一の瀬上流',
      '茨城県かすみがうら市三ツ木',
      '茨城県かすみがうら市上大堤',
      '茨城県かすみがうら市上軽部',
      '茨城県かすみがうら市下大堤',
      '茨城県かすみがうら市下軽部',
      '茨城県かすみがうら市中台',
      '茨城県かすみがうら市加茂',
      '茨城県かすみがうら市南根本',
      '茨城県かすみがうら市坂',
      '茨城県かすみがうら市大和田',
      '茨城県かすみがうら市安食',
      '茨城県かすみがうら市宍倉',
      '茨城県かすみがうら市岩坪',
      '茨城県かすみがうら市志戸崎',
      '茨城県かすみがうら市戸崎',
      '茨城県かすみがうら市有河',
      '茨城県かすみがうら市柏崎',
      '茨城県かすみがうら市深谷',
      '茨城県かすみがうら市牛渡',
      '茨城県かすみがうら市田伏',
      '茨城県かすみがうら市男神',
      '茨城県かすみがうら市西成井',
      '茨城県つくば市',
      '茨城県ひたちなか市',
      '茨城県土浦市',
      '茨城県東茨城郡城里町',
      '茨城県東茨城郡大洗町',
      '茨城県東茨城郡茨城町',
      '茨城県水戸市',
      '茨城県牛久市',
      '茨城県稲敷市',
      '茨城県稲敷郡美浦村',
      '茨城県稲敷郡阿見町',
      '茨城県那珂市',
      '茨城県那珂郡'
    ],
    'local_code_digits' => 3
  },
  '291' => {
    'addresses' => [
      '茨城県行方市三和',
      '茨城県行方市両宿',
      '茨城県行方市中根',
      '茨城県行方市内宿',
      '茨城県行方市北高岡',
      '茨城県行方市南高岡',
      '茨城県行方市吉川',
      '茨城県行方市小幡',
      '茨城県行方市小貫',
      '茨城県行方市山田',
      '茨城県行方市成田',
      '茨城県行方市次木',
      '茨城県行方市繁昌',
      '茨城県行方市行戸',
      '茨城県行方市長野江',
      '茨城県鉾田市'
    ],
    'local_code_digits' => 2
  },
  '293' => {
    'addresses' => [
      '茨城県北茨城市',
      '茨城県高萩市'
    ],
    'local_code_digits' => 2
  },
  '294' => {
    'addresses' => [
      '茨城県常陸太田市',
      '茨城県日立市'
    ],
    'local_code_digits' => 2
  },
  '295' => {
    'addresses' => [
      '茨城県久慈郡',
      '茨城県常陸大宮市'
    ],
    'local_code_digits' => 2
  },
  '296' => {
    'addresses' => [
      '栃木県小山市中島',
      '栃木県小山市中河原',
      '栃木県小山市梁',
      '栃木県小山市福良',
      '茨城県下妻市',
      '茨城県東茨城郡城里町上赤沢',
      '茨城県東茨城郡城里町下赤沢',
      '茨城県東茨城郡城里町塩子',
      '茨城県東茨城郡城里町大網',
      '茨城県東茨城郡城里町小勝',
      '茨城県東茨城郡城里町徳蔵',
      '茨城県東茨城郡城里町真端',
      '茨城県桜川市',
      '茨城県桜川市大国玉',
      '茨城県桜川市大曽根',
      '茨城県桜川市本木',
      '茨城県桜川市東飯田',
      '茨城県桜川市真壁町',
      '茨城県桜川市羽田',
      '茨城県桜川市金敷',
      '茨城県桜川市阿部田',
      '茨城県桜川市青木',
      '茨城県桜川市高久',
      '茨城県桜川市高森',
      '茨城県笠間市',
      '茨城県筑西市',
      '茨城県結城市',
      '茨城県結城郡'
    ],
    'local_code_digits' => 2
  },
  '297' => {
    'addresses' => [
      '茨城県つくばみらい市',
      '茨城県北相馬郡',
      '茨城県取手市',
      '茨城県坂東市',
      '茨城県守谷市',
      '茨城県常総市',
      '茨城県稲敷市上根本',
      '茨城県稲敷市下太田',
      '茨城県稲敷市下根本',
      '茨城県稲敷市中山',
      '茨城県稲敷市伊佐津',
      '茨城県稲敷市伊崎',
      '茨城県稲敷市南太田',
      '茨城県稲敷市堀川',
      '茨城県稲敷市太田',
      '茨城県稲敷市寺内',
      '茨城県稲敷市小野',
      '茨城県稲敷市戌渡',
      '茨城県稲敷市柴崎',
      '茨城県稲敷市狸穴',
      '茨城県稲敷市羽賀浦',
      '茨城県稲敷市角崎',
      '茨城県稲敷郡河内町',
      '茨城県龍ヶ崎市'
    ],
    'local_code_digits' => 2
  },
  '299' => {
    'addresses' => [
      '茨城県かすみがうら市',
      '茨城県小美玉市',
      '茨城県潮来市',
      '茨城県石岡市',
      '茨城県神栖市',
      '茨城県稲敷市三島',
      '茨城県稲敷市上之島',
      '茨城県稲敷市上須田',
      '茨城県稲敷市下須田',
      '茨城県稲敷市下須田新田',
      '茨城県稲敷市中島',
      '茨城県稲敷市今',
      '茨城県稲敷市伊佐部',
      '茨城県稲敷市佐原',
      '茨城県稲敷市佐原下手',
      '茨城県稲敷市佐原組新田',
      '茨城県稲敷市余津谷',
      '茨城県稲敷市光葉',
      '茨城県稲敷市八千石',
      '茨城県稲敷市八筋川',
      '茨城県稲敷市六角',
      '茨城県稲敷市四ッ谷',
      '茨城県稲敷市境島',
      '茨城県稲敷市大島',
      '茨城県稲敷市市崎',
      '茨城県稲敷市幸田',
      '茨城県稲敷市手賀組新田',
      '茨城県稲敷市押砂',
      '茨城県稲敷市新橋',
      '茨城県稲敷市曲渕',
      '茨城県稲敷市本新',
      '茨城県稲敷市東大沼',
      '茨城県稲敷市橋向',
      '茨城県稲敷市清久島',
      '茨城県稲敷市清水',
      '茨城県稲敷市町田',
      '茨城県稲敷市石納',
      '茨城県稲敷市神崎本宿',
      '茨城県稲敷市神崎神宿',
      '茨城県稲敷市福田',
      '茨城県稲敷市結佐',
      '茨城県稲敷市脇川',
      '茨城県稲敷市西代',
      '茨城県稲敷市野間谷原',
      '茨城県稲敷市釜井',
      '茨城県稲敷市阿波崎',
      '茨城県稲敷市阿波崎新田',
      '茨城県稲敷市飯島',
      '茨城県笠間市上郷',
      '茨城県笠間市下郷',
      '茨城県笠間市吉岡',
      '茨城県笠間市土師',
      '茨城県笠間市安居',
      '茨城県笠間市市野谷',
      '茨城県笠間市押辺',
      '茨城県笠間市泉',
      '茨城県笠間市泉市野谷入会地',
      '茨城県笠間市福島',
      '茨城県行方市',
      '茨城県行方市井上',
      '茨城県行方市井上藤井',
      '茨城県行方市八木蒔',
      '茨城県行方市手賀',
      '茨城県行方市捻木',
      '茨城県行方市沖洲',
      '茨城県行方市浜',
      '茨城県行方市玉造乙',
      '茨城県行方市玉造甲',
      '茨城県行方市羽生',
      '茨城県行方市芹沢',
      '茨城県行方市若海',
      '茨城県行方市荒宿',
      '茨城県行方市藤井',
      '茨城県行方市西蓮寺',
      '茨城県行方市谷島',
      '茨城県鹿嶋市'
    ],
    'local_code_digits' => 2
  },
  '3' => {
    'addresses' => [
      '東京都三鷹市中原一丁目',
      '東京都世田谷区',
      '東京都中央区',
      '東京都中野区',
      '東京都北区',
      '東京都千代田区',
      '東京都台東区',
      '東京都品川区',
      '東京都墨田区',
      '東京都大田区',
      '東京都文京区',
      '東京都新宿区',
      '東京都杉並区',
      '東京都板橋区',
      '東京都江戸川区',
      '東京都江東区',
      '東京都渋谷区',
      '東京都港区',
      '東京都狛江市',
      '東京都目黒区',
      '東京都練馬区',
      '東京都荒川区',
      '東京都葛飾区',
      '東京都調布市仙川町',
      '東京都調布市入間町',
      '東京都調布市国領町八丁目',
      '東京都調布市東つつじヶ丘',
      '東京都調布市緑ヶ丘',
      '東京都調布市若葉町',
      '東京都調布市西つつじヶ丘二丁目',
      '東京都豊島区',
      '東京都足立区'
    ],
    'local_code_digits' => 4
  },
  '4' => {
    'addresses' => [
      '千葉県我孫子市',
      '千葉県柏市',
      '千葉県流山市',
      '千葉県野田市',
      '千葉県鴨川市',
      '埼玉県入間市',
      '埼玉県所沢市',
      '埼玉県狭山市'
    ],
    'local_code_digits' => 4
  },
  '42' => {
    'addresses' => [
      '埼玉県新座市新堀',
      '埼玉県新座市栗原',
      '埼玉県新座市石神一丁目',
      '埼玉県新座市石神三丁目',
      '埼玉県新座市石神五丁目',
      '埼玉県新座市石神四丁目',
      '埼玉県新座市西堀',
      '埼玉県新座市野寺一丁目',
      '埼玉県新座市野寺五丁目',
      '埼玉県日高市',
      '埼玉県飯能市',
      '東京都あきる野市',
      '東京都八王子市',
      '東京都国分寺市',
      '東京都国分寺市光町',
      '東京都国分寺市内藤',
      '東京都国分寺市富士本',
      '東京都国分寺市戸倉三丁目',
      '東京都国分寺市日吉町三丁目',
      '東京都国分寺市日吉町二丁目',
      '東京都国分寺市西町',
      '東京都国分寺市高木町',
      '東京都国立市',
      '東京都多摩市',
      '東京都小平市',
      '東京都小平市花小金井',
      '東京都小平市花小金井南町',
      '東京都小平市鈴木町二丁目',
      '東京都小金井市',
      '東京都府中市',
      '東京都府中市北山町',
      '東京都府中市押立町五丁目',
      '東京都府中市押立町四丁目',
      '東京都府中市西原町三丁目',
      '東京都府中市西原町二丁目',
      '東京都府中市西原町四丁目',
      '東京都府中市西府町四丁目',
      '東京都日野市',
      '東京都昭島市',
      '東京都東久留米市',
      '東京都東大和市',
      '東京都東村山市',
      '東京都武蔵村山市',
      '東京都清瀬市',
      '東京都狛江市西和泉',
      '東京都町田市',
      '東京都福生市',
      '東京都稲城市',
      '東京都立川市',
      '東京都羽村市',
      '東京都西多摩郡',
      '東京都西東京市',
      '東京都調布市',
      '神奈川県座間市相模が丘一丁目',
      '神奈川県座間市相模が丘五丁目',
      '神奈川県相模原市',
      '神奈川県相模原市緑区与瀬',
      '神奈川県相模原市緑区与瀬本町',
      '神奈川県相模原市緑区佐野川',
      '神奈川県相模原市緑区千木良',
      '神奈川県相模原市緑区吉野',
      '神奈川県相模原市緑区名倉',
      '神奈川県相模原市緑区寸沢嵐',
      '神奈川県相模原市緑区小原',
      '神奈川県相模原市緑区小渕',
      '神奈川県相模原市緑区日連',
      '神奈川県相模原市緑区澤井',
      '神奈川県相模原市緑区牧野',
      '神奈川県相模原市緑区若柳'
    ],
    'local_code_digits' => 3
  },
  '422' => {
    'addresses' => [
      '東京都三鷹市',
      '東京都小金井市東町三丁目',
      '東京都小金井市東町二丁目',
      '東京都小金井市梶野町一丁目',
      '東京都小金井市梶野町三丁目',
      '東京都小金井市梶野町二丁目',
      '東京都小金井市梶野町四丁目',
      '東京都武蔵野市',
      '東京都西東京市新町',
      '東京都調布市深大寺東町七丁目',
      '東京都調布市野水'
    ],
    'local_code_digits' => 2
  },
  '428' => {
    'addresses' => [
      '山梨県北都留郡',
      '東京都西多摩郡奥多摩町',
      '東京都青梅市'
    ],
    'local_code_digits' => 2
  },
  '43' => {
    'addresses' => [
      '千葉県佐倉市',
      '千葉県八街市',
      '千葉県千葉市',
      '千葉県印旛郡酒々井町',
      '千葉県四街道市'
    ],
    'local_code_digits' => 3
  },
  '436' => {
    'addresses' => [
      '千葉県市原市'
    ],
    'local_code_digits' => 2
  },
  '438' => {
    'addresses' => [
      '千葉県木更津市',
      '千葉県袖ヶ浦市'
    ],
    'local_code_digits' => 2
  },
  '439' => {
    'addresses' => [
      '千葉県君津市',
      '千葉県富津市'
    ],
    'local_code_digits' => 2
  },
  '44' => {
    'addresses' => [
      '東京都町田市三輪町',
      '東京都町田市三輪緑山',
      '神奈川県川崎市'
    ],
    'local_code_digits' => 3
  },
  '45' => {
    'addresses' => [
      '神奈川県横浜市'
    ],
    'local_code_digits' => 3
  },
  '46' => {
    'addresses' => [
      '神奈川県三浦市',
      '神奈川県三浦郡',
      '神奈川県厚木市',
      '神奈川県大和市',
      '神奈川県座間市',
      '神奈川県愛甲郡',
      '神奈川県横須賀市',
      '神奈川県海老名市',
      '神奈川県相模原市南区新戸',
      '神奈川県相模原市南区新磯野一丁目',
      '神奈川県相模原市南区新磯野三丁目',
      '神奈川県相模原市南区新磯野五丁目',
      '神奈川県相模原市南区新磯野四丁目',
      '神奈川県相模原市南区相武台',
      '神奈川県相模原市南区相武台団地',
      '神奈川県相模原市南区磯部',
      '神奈川県逗子市'
    ],
    'local_code_digits' => 3
  },
  '460' => {
    'addresses' => [
      '神奈川県足柄下郡箱根町',
      '静岡県裾野市茶畑'
    ],
    'local_code_digits' => 2
  },
  '463' => {
    'addresses' => [
      '神奈川県中郡',
      '神奈川県伊勢原市',
      '神奈川県平塚市',
      '神奈川県秦野市'
    ],
    'local_code_digits' => 2
  },
  '465' => {
    'addresses' => [
      '神奈川県南足柄市',
      '神奈川県小田原市',
      '神奈川県足柄上郡',
      '神奈川県足柄下郡湯河原町',
      '神奈川県足柄下郡真鶴町',
      '静岡県熱海市泉元宮上分',
      '静岡県熱海市泉元宮下分',
      '静岡県熱海市泉元門川分'
    ],
    'local_code_digits' => 2
  },
  '466' => {
    'addresses' => [
      '神奈川県藤沢市'
    ],
    'local_code_digits' => 2
  },
  '467' => {
    'addresses' => [
      '神奈川県綾瀬市',
      '神奈川県茅ヶ崎市',
      '神奈川県逗子市小坪',
      '神奈川県鎌倉市',
      '神奈川県高座郡'
    ],
    'local_code_digits' => 2
  },
  '47' => {
    'addresses' => [
      '千葉県八千代市',
      '千葉県千葉市花見川区柏井',
      '千葉県千葉市花見川区柏井町',
      '千葉県千葉市花見川区横戸町',
      '千葉県市川市',
      '千葉県松戸市',
      '千葉県浦安市',
      '千葉県白井市',
      '千葉県習志野市',
      '千葉県船橋市',
      '千葉県船橋市上山町一丁目',
      '千葉県船橋市二子町',
      '千葉県船橋市古作',
      '千葉県船橋市古作町',
      '千葉県船橋市本中山',
      '千葉県船橋市本郷町',
      '千葉県船橋市東中山',
      '千葉県船橋市藤原一丁目',
      '千葉県船橋市藤原二丁目',
      '千葉県船橋市西船七丁目',
      '千葉県船橋市西船五丁目',
      '千葉県船橋市西船六丁目',
      '千葉県鎌ヶ谷市',
      '千葉県鎌ヶ谷市くぬぎ山一丁目',
      '千葉県鎌ヶ谷市くぬぎ山三丁目',
      '千葉県鎌ヶ谷市くぬぎ山二丁目',
      '千葉県鎌ヶ谷市くぬぎ山四丁目'
    ],
    'local_code_digits' => 3
  },
  '470' => {
    'addresses' => [
      '千葉県いすみ市',
      '千葉県勝浦市',
      '千葉県南房総市',
      '千葉県夷隅郡',
      '千葉県安房郡',
      '千葉県館山市'
    ],
    'local_code_digits' => 2
  },
  '475' => {
    'addresses' => [
      '千葉県大網白里市',
      '千葉県山武市',
      '千葉県山武郡九十九里町',
      '千葉県東金市',
      '千葉県茂原市',
      '千葉県長生郡'
    ],
    'local_code_digits' => 2
  },
  '476' => {
    'addresses' => [
      '千葉県印旛郡',
      '千葉県印西市',
      '千葉県富里市',
      '千葉県成田市'
    ],
    'local_code_digits' => 2
  },
  '478' => {
    'addresses' => [
      '千葉県香取市',
      '千葉県香取郡東庄町',
      '千葉県香取郡神崎町'
    ],
    'local_code_digits' => 2
  },
  '479' => {
    'addresses' => [
      '千葉県匝瑳市',
      '千葉県山武市松尾町',
      '千葉県山武郡',
      '千葉県旭市',
      '千葉県銚子市',
      '千葉県香取郡多古町',
      '茨城県神栖市土合中央',
      '茨城県神栖市土合北',
      '茨城県神栖市土合南',
      '茨城県神栖市土合本町',
      '茨城県神栖市土合東',
      '茨城県神栖市土合西',
      '茨城県神栖市太田',
      '茨城県神栖市太田新町',
      '茨城県神栖市柳川',
      '茨城県神栖市柳川中央',
      '茨城県神栖市波崎',
      '茨城県神栖市波崎新港',
      '茨城県神栖市矢田部',
      '茨城県神栖市砂山',
      '茨城県神栖市若松中央',
      '茨城県神栖市須田'
    ],
    'local_code_digits' => 2
  },
  '48' => {
    'addresses' => [
      '埼玉県さいたま市',
      '埼玉県三郷市',
      '埼玉県上尾市',
      '埼玉県八潮市',
      '埼玉県北本市',
      '埼玉県北葛飾郡',
      '埼玉県北足立郡',
      '埼玉県吉川市',
      '埼玉県和光市',
      '埼玉県大里郡',
      '埼玉県富士見市水谷東三丁目',
      '埼玉県富士見市水谷東二丁目',
      '埼玉県川口市',
      '埼玉県志木市',
      '埼玉県戸田市',
      '埼玉県新座市',
      '埼玉県春日部市',
      '埼玉県朝霞市',
      '埼玉県桶川市',
      '埼玉県深谷市',
      '埼玉県熊谷市',
      '埼玉県羽生市',
      '埼玉県草加市',
      '埼玉県蓮田市',
      '埼玉県蕨市',
      '埼玉県行田市',
      '埼玉県越谷市',
      '埼玉県鴻巣市'
    ],
    'local_code_digits' => 3
  },
  '480' => {
    'addresses' => [
      '埼玉県久喜市',
      '埼玉県加須市',
      '埼玉県北葛飾郡杉戸町',
      '埼玉県南埼玉郡',
      '埼玉県幸手市',
      '埼玉県白岡市'
    ],
    'local_code_digits' => 2
  },
  '49' => {
    'addresses' => [
      '埼玉県ふじみ野市',
      '埼玉県入間郡',
      '埼玉県坂戸市',
      '埼玉県富士見市',
      '埼玉県川越市',
      '埼玉県比企郡川島町',
      '埼玉県比企郡鳩山町',
      '埼玉県鶴ヶ島市'
    ],
    'local_code_digits' => 3
  },
  '493' => {
    'addresses' => [
      '埼玉県東松山市',
      '埼玉県比企郡ときがわ町',
      '埼玉県比企郡吉見町',
      '埼玉県比企郡小川町',
      '埼玉県比企郡嵐山町',
      '埼玉県比企郡滑川町',
      '埼玉県熊谷市冑山',
      '埼玉県熊谷市吉所敷',
      '埼玉県熊谷市向谷',
      '埼玉県熊谷市小八林',
      '埼玉県熊谷市沼黒',
      '埼玉県熊谷市津田',
      '埼玉県熊谷市津田新田',
      '埼玉県熊谷市玉作',
      '埼玉県熊谷市相上',
      '埼玉県熊谷市箕輪',
      '埼玉県熊谷市船木台',
      '埼玉県熊谷市高本',
      '埼玉県秩父郡東秩父村'
    ],
    'local_code_digits' => 2
  },
  '494' => {
    'addresses' => [
      '埼玉県秩父市',
      '埼玉県秩父郡'
    ],
    'local_code_digits' => 2
  },
  '495' => {
    'addresses' => [
      '埼玉県児玉郡上里町',
      '埼玉県児玉郡神川町',
      '埼玉県児玉郡美里町',
      '埼玉県本庄市'
    ],
    'local_code_digits' => 2
  },
  '4992' => {
    'addresses' => [
      '東京都利島村',
      '東京都大島町',
      '東京都新島本村',
      '東京都神津島村'
    ],
    'local_code_digits' => 1
  },
  '4994' => {
    'addresses' => [
      '東京都三宅村',
      '東京都御蔵島村'
    ],
    'local_code_digits' => 1
  },
  '4996' => {
    'addresses' => [
      '東京都八丈町',
      '東京都青ヶ島村'
    ],
    'local_code_digits' => 1
  },
  '4998' => {
    'addresses' => [
      '東京都小笠原村'
    ],
    'local_code_digits' => 1
  },
  '52' => {
    'addresses' => [
      '愛知県あま市',
      '愛知県名古屋市',
      '愛知県尾張旭市吉岡町',
      '愛知県尾張旭市庄南町',
      '愛知県尾張旭市東名西町',
      '愛知県尾張旭市東山町',
      '愛知県尾張旭市西山町',
      '愛知県尾張旭市霞ヶ丘町',
      '愛知県日進市梅森町',
      '愛知県日進市浅田町',
      '愛知県日進市赤池',
      '愛知県日進市赤池町',
      '愛知県日進市香久山',
      '愛知県東海市',
      '愛知県海部郡大治町',
      '愛知県清須市'
    ],
    'local_code_digits' => 3
  },
  '53' => {
    'addresses' => [
      '静岡県浜松市',
      '静岡県湖西市'
    ],
    'local_code_digits' => 3
  },
  '531' => {
    'addresses' => [
      '愛知県田原市'
    ],
    'local_code_digits' => 2
  },
  '532' => {
    'addresses' => [
      '愛知県豊橋市'
    ],
    'local_code_digits' => 2
  },
  '533' => {
    'addresses' => [
      '愛知県蒲郡市',
      '愛知県豊川市'
    ],
    'local_code_digits' => 2
  },
  '536' => {
    'addresses' => [
      '愛知県北設楽郡',
      '愛知県新城市'
    ],
    'local_code_digits' => 2
  },
  '537' => {
    'addresses' => [
      '静岡県御前崎市',
      '静岡県掛川市',
      '静岡県菊川市'
    ],
    'local_code_digits' => 2
  },
  '538' => {
    'addresses' => [
      '静岡県周智郡',
      '静岡県磐田市',
      '静岡県袋井市'
    ],
    'local_code_digits' => 2
  },
  '539' => {
    'addresses' => [
      '静岡県磐田市万瀬',
      '静岡県磐田市三家',
      '静岡県磐田市上神増',
      '静岡県磐田市上野部',
      '静岡県磐田市下神増',
      '静岡県磐田市下野部',
      '静岡県磐田市合代島',
      '静岡県磐田市壱貫地',
      '静岡県磐田市大平',
      '静岡県磐田市大当所',
      '静岡県磐田市家田',
      '静岡県磐田市岩室',
      '静岡県磐田市平松',
      '静岡県磐田市惣兵衛下新田',
      '静岡県磐田市掛下',
      '静岡県磐田市敷地',
      '静岡県磐田市新開',
      '静岡県磐田市松之木島',
      '静岡県磐田市社山',
      '静岡県磐田市神増',
      '静岡県磐田市虫生'
    ],
    'local_code_digits' => 2
  },
  '54' => {
    'addresses' => [
      '静岡県焼津市',
      '静岡県藤枝市',
      '静岡県静岡市'
    ],
    'local_code_digits' => 3
  },
  '544' => {
    'addresses' => [
      '静岡県富士宮市'
    ],
    'local_code_digits' => 2
  },
  '545' => {
    'addresses' => [
      '静岡県富士市'
    ],
    'local_code_digits' => 2
  },
  '547' => {
    'addresses' => [
      '静岡県島田市',
      '静岡県榛原郡川根本町'
    ],
    'local_code_digits' => 2
  },
  '548' => {
    'addresses' => [
      '静岡県御前崎市御前崎',
      '静岡県御前崎市港',
      '静岡県御前崎市白羽',
      '静岡県榛原郡吉田町',
      '静岡県牧之原市',
      '静岡県菊川市倉沢',
      '静岡県菊川市小沢',
      '静岡県菊川市沢水加',
      '静岡県菊川市牛渕'
    ],
    'local_code_digits' => 2
  },
  '55' => {
    'addresses' => [
      '山梨県中央市',
      '山梨県中巨摩郡',
      '山梨県南アルプス市',
      '山梨県甲府市',
      '山梨県甲斐市',
      '山梨県笛吹市',
      '山梨県西八代郡市川三郷町',
      '静岡県三島市',
      '静岡県伊豆の国市',
      '静岡県沼津市',
      '静岡県田方郡',
      '静岡県裾野市',
      '静岡県駿東郡清水町',
      '静岡県駿東郡長泉町'
    ],
    'local_code_digits' => 3
  },
  '550' => {
    'addresses' => [
      '静岡県御殿場市',
      '静岡県駿東郡小山町'
    ],
    'local_code_digits' => 2
  },
  '551' => {
    'addresses' => [
      '山梨県北杜市',
      '山梨県甲斐市下今井',
      '山梨県甲斐市團子新居',
      '山梨県甲斐市大垈',
      '山梨県甲斐市宇津谷',
      '山梨県甲斐市岩森',
      '山梨県甲斐市志田',
      '山梨県甲斐市菖蒲澤',
      '山梨県甲斐市龍地',
      '山梨県韮崎市'
    ],
    'local_code_digits' => 2
  },
  '553' => {
    'addresses' => [
      '山梨県山梨市',
      '山梨県甲州市',
      '山梨県笛吹市一宮町',
      '山梨県笛吹市春日居町'
    ],
    'local_code_digits' => 2
  },
  '554' => {
    'addresses' => [
      '山梨県上野原市',
      '山梨県南都留郡道志村',
      '山梨県大月市',
      '山梨県都留市'
    ],
    'local_code_digits' => 2
  },
  '555' => {
    'addresses' => [
      '山梨県南都留郡',
      '山梨県富士吉田市',
      '山梨県甲府市古関町',
      '山梨県甲府市梯町'
    ],
    'local_code_digits' => 2
  },
  '556' => {
    'addresses' => [
      '山梨県南巨摩郡南部町',
      '山梨県南巨摩郡富士川町',
      '山梨県南巨摩郡早川町',
      '山梨県南巨摩郡身延町',
      '山梨県南巨摩郡身延町上八木沢',
      '山梨県南巨摩郡身延町下八木沢',
      '山梨県南巨摩郡身延町下山',
      '山梨県南巨摩郡身延町丸滝',
      '山梨県南巨摩郡身延町光子沢',
      '山梨県南巨摩郡身延町和田',
      '山梨県南巨摩郡身延町大垈',
      '山梨県南巨摩郡身延町大城',
      '山梨県南巨摩郡身延町大島',
      '山梨県南巨摩郡身延町大崩',
      '山梨県南巨摩郡身延町大野',
      '山梨県南巨摩郡身延町小田船原',
      '山梨県南巨摩郡身延町帯金',
      '山梨県南巨摩郡身延町梅平',
      '山梨県南巨摩郡身延町椿草里',
      '山梨県南巨摩郡身延町樋之上',
      '山梨県南巨摩郡身延町横根中',
      '山梨県南巨摩郡身延町波木井',
      '山梨県南巨摩郡身延町清子',
      '山梨県南巨摩郡身延町相又',
      '山梨県南巨摩郡身延町粟倉',
      '山梨県南巨摩郡身延町角打',
      '山梨県南巨摩郡身延町身延',
      '山梨県南巨摩郡身延町門野',
      '山梨県西八代郡市川三郷町五八',
      '山梨県西八代郡市川三郷町宮原',
      '山梨県西八代郡市川三郷町寺所',
      '山梨県西八代郡市川三郷町岩下',
      '山梨県西八代郡市川三郷町岩間',
      '山梨県西八代郡市川三郷町楠甫',
      '山梨県西八代郡市川三郷町落居',
      '山梨県西八代郡市川三郷町葛籠沢',
      '山梨県西八代郡市川三郷町鴨狩津向'
    ],
    'local_code_digits' => 2
  },
  '557' => {
    'addresses' => [
      '静岡県伊東市',
      '静岡県伊豆市冷川',
      '静岡県熱海市',
      '静岡県賀茂郡東伊豆町'
    ],
    'local_code_digits' => 2
  },
  '558' => {
    'addresses' => [
      '静岡県下田市',
      '静岡県伊豆の国市三福',
      '静岡県伊豆の国市下畑',
      '静岡県伊豆の国市中島',
      '静岡県伊豆の国市吉田',
      '静岡県伊豆の国市大仁',
      '静岡県伊豆の国市守木',
      '静岡県伊豆の国市宗光寺',
      '静岡県伊豆の国市御門',
      '静岡県伊豆の国市星和',
      '静岡県伊豆の国市浮橋',
      '静岡県伊豆の国市田中山',
      '静岡県伊豆の国市田京',
      '静岡県伊豆の国市田原野',
      '静岡県伊豆の国市白山堂',
      '静岡県伊豆の国市神島',
      '静岡県伊豆の国市立花',
      '静岡県伊豆の国市長者原',
      '静岡県伊豆市',
      '静岡県沼津市井田',
      '静岡県沼津市戸田',
      '静岡県賀茂郡南伊豆町',
      '静岡県賀茂郡松崎町',
      '静岡県賀茂郡河津町',
      '静岡県賀茂郡西伊豆町'
    ],
    'local_code_digits' => 2
  },
  '561' => {
    'addresses' => [
      '愛知県みよし市',
      '愛知県尾張旭市',
      '愛知県愛知郡',
      '愛知県日進市',
      '愛知県瀬戸市',
      '愛知県長久手市'
    ],
    'local_code_digits' => 2
  },
  '562' => {
    'addresses' => [
      '愛知県大府市',
      '愛知県東海市中ノ池',
      '愛知県東海市中央町',
      '愛知県東海市元浜町',
      '愛知県東海市加木屋町',
      '愛知県東海市大田町',
      '愛知県東海市横須賀町',
      '愛知県東海市養父町',
      '愛知県東海市高横須賀町',
      '愛知県知多市',
      '愛知県知多郡東浦町',
      '愛知県豊明市'
    ],
    'local_code_digits' => 2
  },
  '563' => {
    'addresses' => [
      '愛知県西尾市'
    ],
    'local_code_digits' => 2
  },
  '564' => {
    'addresses' => [
      '愛知県岡崎市',
      '愛知県額田郡'
    ],
    'local_code_digits' => 2
  },
  '565' => {
    'addresses' => [
      '愛知県豊田市'
    ],
    'local_code_digits' => 2
  },
  '566' => {
    'addresses' => [
      '愛知県刈谷市',
      '愛知県安城市',
      '愛知県知立市',
      '愛知県碧南市',
      '愛知県高浜市'
    ],
    'local_code_digits' => 2
  },
  '567' => {
    'addresses' => [
      '三重県桑名郡',
      '愛知県弥富市',
      '愛知県愛西市',
      '愛知県津島市',
      '愛知県海部郡',
      '愛知県稲沢市平和町'
    ],
    'local_code_digits' => 2
  },
  '568' => {
    'addresses' => [
      '愛知県北名古屋市',
      '愛知県小牧市',
      '愛知県春日井市',
      '愛知県犬山市',
      '愛知県西春日井郡'
    ],
    'local_code_digits' => 2
  },
  '569' => {
    'addresses' => [
      '愛知県半田市',
      '愛知県常滑市',
      '愛知県知多市南粕谷',
      '愛知県知多市新広見',
      '愛知県知多市新舞子',
      '愛知県知多市旭南',
      '愛知県知多市神田',
      '愛知県知多市金沢',
      '愛知県知多郡南知多町',
      '愛知県知多郡武豊町',
      '愛知県知多郡美浜町',
      '愛知県知多郡阿久比町'
    ],
    'local_code_digits' => 2
  },
  '572' => {
    'addresses' => [
      '岐阜県土岐市',
      '岐阜県多治見市',
      '岐阜県恵那市明智町吉良見',
      '岐阜県瑞浪市'
    ],
    'local_code_digits' => 2
  },
  '573' => {
    'addresses' => [
      '岐阜県中津川市',
      '岐阜県中津川市蛭川',
      '岐阜県恵那市',
      '長野県木曽郡南木曽町田立'
    ],
    'local_code_digits' => 2
  },
  '574' => {
    'addresses' => [
      '岐阜県加茂郡七宗町',
      '岐阜県加茂郡八百津町',
      '岐阜県加茂郡坂祝町',
      '岐阜県加茂郡富加町',
      '岐阜県加茂郡川辺町',
      '岐阜県加茂郡東白川村',
      '岐阜県加茂郡白川町',
      '岐阜県可児市',
      '岐阜県可児郡',
      '岐阜県美濃加茂市'
    ],
    'local_code_digits' => 2
  },
  '575' => {
    'addresses' => [
      '岐阜県美濃市',
      '岐阜県郡上市',
      '岐阜県関市'
    ],
    'local_code_digits' => 2
  },
  '576' => {
    'addresses' => [
      '岐阜県下呂市'
    ],
    'local_code_digits' => 2
  },
  '5769' => {
    'addresses' => [
      '岐阜県大野郡',
      '岐阜県高山市荘川町'
    ],
    'local_code_digits' => 1
  },
  '577' => {
    'addresses' => [
      '岐阜県飛騨市',
      '岐阜県高山市'
    ],
    'local_code_digits' => 2
  },
  '578' => {
    'addresses' => [
      '岐阜県飛騨市神岡町',
      '岐阜県高山市上宝町',
      '岐阜県高山市奥飛騨温泉郷'
    ],
    'local_code_digits' => 2
  },
  '58' => {
    'addresses' => [
      '岐阜県各務原市',
      '岐阜県岐阜市',
      '岐阜県本巣郡',
      '岐阜県瑞穂市',
      '岐阜県羽島市',
      '岐阜県羽島郡'
    ],
    'local_code_digits' => 3
  },
  '581' => {
    'addresses' => [
      '岐阜県山県市',
      '岐阜県揖斐郡揖斐川町徳山',
      '岐阜県本巣市',
      '岐阜県関市板取',
      '岐阜県関市洞戸大野',
      '岐阜県関市洞戸小坂',
      '岐阜県関市洞戸小瀬見',
      '岐阜県関市洞戸尾倉',
      '岐阜県関市洞戸市場',
      '岐阜県関市洞戸栗原',
      '岐阜県関市洞戸片',
      '岐阜県関市洞戸菅谷',
      '岐阜県関市洞戸通元寺',
      '岐阜県関市洞戸阿部',
      '岐阜県関市洞戸飛瀬',
      '岐阜県関市洞戸高見',
      '岐阜県関市洞戸高賀',
      '岐阜県関市洞戸黒谷'
    ],
    'local_code_digits' => 2
  },
  '584' => {
    'addresses' => [
      '岐阜県不破郡',
      '岐阜県大垣市',
      '岐阜県安八郡',
      '岐阜県揖斐郡池田町市橋',
      '岐阜県海津市',
      '岐阜県瑞穂市呂久',
      '岐阜県養老郡'
    ],
    'local_code_digits' => 2
  },
  '585' => {
    'addresses' => [
      '岐阜県揖斐郡'
    ],
    'local_code_digits' => 2
  },
  '586' => {
    'addresses' => [
      '岐阜県各務原市川島北山町',
      '岐阜県各務原市川島小網町',
      '岐阜県各務原市川島松倉町',
      '岐阜県各務原市川島松原町',
      '岐阜県各務原市川島河田町',
      '岐阜県各務原市川島渡町',
      '岐阜県各務原市川島竹早町',
      '岐阜県各務原市川島笠田町',
      '岐阜県各務原市川島緑町',
      '愛知県一宮市',
      '愛知県稲沢市横野町',
      '愛知県稲沢市生出上山町',
      '愛知県稲沢市生出東道根町',
      '愛知県稲沢市生出横西町',
      '愛知県稲沢市生出河戸町',
      '愛知県稲沢市生出西道根町',
      '愛知県稲沢市生出郷前町',
      '愛知県稲沢市西島町'
    ],
    'local_code_digits' => 2
  },
  '587' => {
    'addresses' => [
      '愛知県丹羽郡',
      '愛知県岩倉市',
      '愛知県江南市',
      '愛知県稲沢市'
    ],
    'local_code_digits' => 2
  },
  '59' => {
    'addresses' => [
      '三重県三重郡',
      '三重県四日市市',
      '三重県津市',
      '三重県鈴鹿市'
    ],
    'local_code_digits' => 3
  },
  '594' => {
    'addresses' => [
      '三重県いなべ市',
      '三重県員弁郡',
      '三重県桑名市'
    ],
    'local_code_digits' => 2
  },
  '595' => {
    'addresses' => [
      '三重県亀山市',
      '三重県伊賀市',
      '三重県名張市'
    ],
    'local_code_digits' => 2
  },
  '596' => {
    'addresses' => [
      '三重県伊勢市',
      '三重県多気郡明和町',
      '三重県度会郡南伊勢町古和浦',
      '三重県度会郡南伊勢町大方竈 ',
      '三重県度会郡南伊勢町大江',
      '三重県度会郡南伊勢町奈屋浦',
      '三重県度会郡南伊勢町小方竈',
      '三重県度会郡南伊勢町慥柄浦',
      '三重県度会郡南伊勢町新桑竈',
      '三重県度会郡南伊勢町方座浦',
      '三重県度会郡南伊勢町村山',
      '三重県度会郡南伊勢町東宮',
      '三重県度会郡南伊勢町栃木竈',
      '三重県度会郡南伊勢町棚橋竈',
      '三重県度会郡南伊勢町河内',
      '三重県度会郡南伊勢町神前浦',
      '三重県度会郡南伊勢町贄浦',
      '三重県度会郡南伊勢町道方',
      '三重県度会郡南伊勢町道行竈',
      '三重県度会郡南伊勢町阿曽浦',
      '三重県度会郡度会町',
      '三重県度会郡玉城町'
    ],
    'local_code_digits' => 2
  },
  '597' => {
    'addresses' => [
      '三重県北牟婁郡紀北町',
      '三重県尾鷲市',
      '三重県熊野市'
    ],
    'local_code_digits' => 2
  },
  '5979' => {
    'addresses' => [
      '三重県南牟婁郡御浜町'
    ],
    'local_code_digits' => 1
  },
  '598' => {
    'addresses' => [
      '三重県多気郡多気町',
      '三重県多気郡大台町',
      '三重県度会郡大紀町',
      '三重県松阪市'
    ],
    'local_code_digits' => 2
  },
  '599' => {
    'addresses' => [
      '三重県度会郡南伊勢町',
      '三重県志摩市',
      '三重県鳥羽市'
    ],
    'local_code_digits' => 2
  },
  '6' => {
    'addresses' => [
      '兵庫県尼崎市',
      '大阪府八尾市竹渕',
      '大阪府八尾市竹渕東',
      '大阪府八尾市竹渕西',
      '大阪府吹田市',
      '大阪府大阪市',
      '大阪府守口市',
      '大阪府摂津市一津屋',
      '大阪府摂津市三島',
      '大阪府摂津市別府',
      '大阪府摂津市北別府町',
      '大阪府摂津市千里丘',
      '大阪府摂津市千里丘東五丁目',
      '大阪府摂津市千里丘東四丁目',
      '大阪府摂津市南別府町',
      '大阪府摂津市南千里丘',
      '大阪府摂津市庄屋',
      '大阪府摂津市新在家',
      '大阪府摂津市東一津屋',
      '大阪府摂津市東別府',
      '大阪府摂津市東正雀',
      '大阪府摂津市正雀',
      '大阪府摂津市正雀本町',
      '大阪府摂津市浜町',
      '大阪府摂津市西一津屋',
      '大阪府東大阪市',
      '大阪府東大阪市岩田町三丁目',
      '大阪府池田市空港',
      '大阪府豊中市',
      '大阪府門真市一番町',
      '大阪府門真市中町',
      '大阪府門真市元町',
      '大阪府門真市古川町',
      '大阪府門真市向島町',
      '大阪府門真市垣内町',
      '大阪府門真市堂山町',
      '大阪府門真市大倉町',
      '大阪府門真市寿町',
      '大阪府門真市小路町',
      '大阪府門真市幸福町',
      '大阪府門真市御堂町',
      '大阪府門真市新橋町',
      '大阪府門真市月出町',
      '大阪府門真市末広町',
      '大阪府門真市本町',
      '大阪府門真市東田町',
      '大阪府門真市松生町',
      '大阪府門真市松葉町',
      '大阪府門真市柳田町',
      '大阪府門真市柳町',
      '大阪府門真市栄町',
      '大阪府門真市桑才新町',
      '大阪府門真市殿島町',
      '大阪府門真市泉町',
      '大阪府門真市浜町',
      '大阪府門真市深田町',
      '大阪府門真市石原町',
      '大阪府門真市速見町'
    ],
    'local_code_digits' => 4
  },
  '72' => {
    'addresses' => [
      '兵庫県伊丹市',
      '兵庫県宝塚市ふじガ丘',
      '兵庫県宝塚市花屋敷つつじガ丘',
      '兵庫県宝塚市花屋敷松ガ丘',
      '兵庫県宝塚市花屋敷荘園',
      '兵庫県宝塚市長尾台',
      '兵庫県宝塚市雲雀丘',
      '兵庫県宝塚市雲雀丘山手',
      '兵庫県川西市',
      '兵庫県川辺郡',
      '大阪府交野市',
      '大阪府八尾市',
      '大阪府四條畷市',
      '大阪府堺市',
      '大阪府大東市',
      '大阪府大阪市平野区長吉川辺四丁目',
      '大阪府大阪市東住吉区矢田七丁目',
      '大阪府大阪狭山市',
      '大阪府富田林市五軒家',
      '大阪府富田林市加太',
      '大阪府富田林市廿山',
      '大阪府富田林市新青葉丘町',
      '大阪府富田林市青葉丘',
      '大阪府寝屋川市',
      '大阪府岸和田市',
      '大阪府摂津市',
      '大阪府東大阪市上六万寺町',
      '大阪府東大阪市上四条町',
      '大阪府東大阪市上石切町',
      '大阪府東大阪市下六万寺町',
      '大阪府東大阪市中新開',
      '大阪府東大阪市中石切町',
      '大阪府東大阪市中野',
      '大阪府東大阪市中鴻池町',
      '大阪府東大阪市五条町',
      '大阪府東大阪市今米',
      '大阪府東大阪市元町',
      '大阪府東大阪市六万寺町',
      '大阪府東大阪市出雲井本町',
      '大阪府東大阪市出雲井町',
      '大阪府東大阪市加納一丁目',
      '大阪府東大阪市加納七丁目',
      '大阪府東大阪市加納三丁目',
      '大阪府東大阪市加納二丁目',
      '大阪府東大阪市加納五丁目',
      '大阪府東大阪市加納八丁目',
      '大阪府東大阪市加納六丁目',
      '大阪府東大阪市加納四丁目',
      '大阪府東大阪市北石切町',
      '大阪府東大阪市北鴻池町',
      '大阪府東大阪市南四条町',
      '大阪府東大阪市南荘町',
      '大阪府東大阪市南鴻池町',
      '大阪府東大阪市古箕輪',
      '大阪府東大阪市吉原',
      '大阪府東大阪市吉田',
      '大阪府東大阪市吉田下島',
      '大阪府東大阪市吉田本町',
      '大阪府東大阪市善根寺町',
      '大阪府東大阪市喜里川町',
      '大阪府東大阪市四条町',
      '大阪府東大阪市宝町',
      '大阪府東大阪市客坊町',
      '大阪府東大阪市山手町',
      '大阪府東大阪市岩田町',
      '大阪府東大阪市島之内',
      '大阪府東大阪市川中',
      '大阪府東大阪市川田',
      '大阪府東大阪市布市町',
      '大阪府東大阪市弥生町',
      '大阪府東大阪市御幸町',
      '大阪府東大阪市新庄',
      '大阪府東大阪市新池島町',
      '大阪府東大阪市新町',
      '大阪府東大阪市新鴻池町',
      '大阪府東大阪市日下町',
      '大阪府東大阪市旭町',
      '大阪府東大阪市昭和町',
      '大阪府東大阪市末広町',
      '大阪府東大阪市本庄中一丁目',
      '大阪府東大阪市本町',
      '大阪府東大阪市東山町',
      '大阪府東大阪市東石切町',
      '大阪府東大阪市東豊浦町',
      '大阪府東大阪市東鴻池町',
      '大阪府東大阪市松原',
      '大阪府東大阪市松原南',
      '大阪府東大阪市桜町',
      '大阪府東大阪市横小路町',
      '大阪府東大阪市横枕',
      '大阪府東大阪市横枕南',
      '大阪府東大阪市横枕西',
      '大阪府東大阪市水走',
      '大阪府東大阪市池之端町',
      '大阪府東大阪市池島町',
      '大阪府東大阪市河内町',
      '大阪府東大阪市玉串元町',
      '大阪府東大阪市玉串町東',
      '大阪府東大阪市玉串町西',
      '大阪府東大阪市瓜生堂一丁目',
      '大阪府東大阪市瓢箪山町',
      '大阪府東大阪市神田町',
      '大阪府東大阪市稲葉',
      '大阪府東大阪市立花町',
      '大阪府東大阪市箕輪',
      '大阪府東大阪市箱殿町',
      '大阪府東大阪市花園本町',
      '大阪府東大阪市花園東町',
      '大阪府東大阪市花園西町',
      '大阪府東大阪市若草町',
      '大阪府東大阪市菱屋東',
      '大阪府東大阪市菱江',
      '大阪府東大阪市西岩田一丁目',
      '大阪府東大阪市西石切町',
      '大阪府東大阪市西鴻池町',
      '大阪府東大阪市角田',
      '大阪府東大阪市豊浦町',
      '大阪府東大阪市額田町',
      '大阪府東大阪市鳥居町',
      '大阪府東大阪市鴻池元町',
      '大阪府東大阪市鴻池徳庵町',
      '大阪府東大阪市鴻池本町',
      '大阪府東大阪市鴻池町',
      '大阪府東大阪市鷹殿町',
      '大阪府松原市',
      '大阪府枚方市',
      '大阪府柏原市',
      '大阪府池田市',
      '大阪府泉佐野市',
      '大阪府泉北郡忠岡町新浜',
      '大阪府泉南市',
      '大阪府泉南郡',
      '大阪府箕面市',
      '大阪府羽曳野市',
      '大阪府茨木市',
      '大阪府藤井寺市',
      '大阪府豊能郡',
      '大阪府貝塚市',
      '大阪府門真市',
      '大阪府阪南市',
      '大阪府高槻市',
      '大阪府高石市'
    ],
    'local_code_digits' => 3
  },
  '721' => {
    'addresses' => [
      '大阪府南河内郡',
      '大阪府富田林市',
      '大阪府河内長野市'
    ],
    'local_code_digits' => 2
  },
  '725' => {
    'addresses' => [
      '大阪府和泉市',
      '大阪府泉北郡',
      '大阪府泉大津市'
    ],
    'local_code_digits' => 2
  },
  '73' => {
    'addresses' => [
      '和歌山県和歌山市',
      '和歌山県海南市',
      '和歌山県海草郡'
    ],
    'local_code_digits' => 3
  },
  '735' => {
    'addresses' => [
      '三重県南牟婁郡紀宝町',
      '和歌山県新宮市',
      '和歌山県東牟婁郡串本町',
      '和歌山県東牟婁郡北山村',
      '和歌山県東牟婁郡古座川町',
      '和歌山県東牟婁郡太地町',
      '和歌山県東牟婁郡那智勝浦町',
      '和歌山県田辺市本宮町'
    ],
    'local_code_digits' => 2
  },
  '736' => {
    'addresses' => [
      '和歌山県伊都郡',
      '和歌山県岩出市',
      '和歌山県橋本市',
      '和歌山県紀の川市'
    ],
    'local_code_digits' => 2
  },
  '737' => {
    'addresses' => [
      '和歌山県伊都郡かつらぎ町花園中南',
      '和歌山県伊都郡かつらぎ町花園久木',
      '和歌山県伊都郡かつらぎ町花園北寺',
      '和歌山県伊都郡かつらぎ町花園新子',
      '和歌山県伊都郡かつらぎ町花園梁瀬',
      '和歌山県伊都郡かつらぎ町花園池ノ窪',
      '和歌山県有田市',
      '和歌山県有田郡'
    ],
    'local_code_digits' => 2
  },
  '738' => {
    'addresses' => [
      '和歌山県御坊市',
      '和歌山県日高郡印南町',
      '和歌山県日高郡日高川町',
      '和歌山県日高郡日高町',
      '和歌山県日高郡由良町',
      '和歌山県日高郡美浜町'
    ],
    'local_code_digits' => 2
  },
  '739' => {
    'addresses' => [
      '和歌山県日高郡みなべ町',
      '和歌山県田辺市',
      '和歌山県西牟婁郡'
    ],
    'local_code_digits' => 2
  },
  '740' => {
    'addresses' => [
      '滋賀県高島市'
    ],
    'local_code_digits' => 2
  },
  '742' => {
    'addresses' => [
      '奈良県奈良市'
    ],
    'local_code_digits' => 2
  },
  '743' => {
    'addresses' => [
      '京都府相楽郡南山城村',
      '京都府相楽郡笠置町',
      '大阪府四條畷市さつきヶ丘',
      '大阪府四條畷市上田原',
      '大阪府四條畷市下田原',
      '大阪府四條畷市田原台',
      '大阪府四條畷市緑風台',
      '奈良県大和郡山市',
      '奈良県天理市',
      '奈良県奈良市上深川町',
      '奈良県奈良市下深川町',
      '奈良県奈良市小倉町',
      '奈良県奈良市月ヶ瀬尾山',
      '奈良県奈良市月ヶ瀬嵩',
      '奈良県奈良市月ヶ瀬月瀬',
      '奈良県奈良市月ヶ瀬桃香野',
      '奈良県奈良市月ヶ瀬石打',
      '奈良県奈良市月ヶ瀬長引',
      '奈良県奈良市来迎寺町',
      '奈良県奈良市荻町',
      '奈良県奈良市藺生町',
      '奈良県奈良市都祁こぶしが丘',
      '奈良県奈良市都祁南之庄町',
      '奈良県奈良市都祁友田町',
      '奈良県奈良市都祁吐山町',
      '奈良県奈良市都祁小山戸町',
      '奈良県奈良市都祁甲岡町',
      '奈良県奈良市都祁白石町',
      '奈良県奈良市都祁相河町',
      '奈良県奈良市都祁馬場町',
      '奈良県奈良市針ヶ別所町',
      '奈良県奈良市針町',
      '奈良県宇陀市室生多田',
      '奈良県宇陀市室生小原',
      '奈良県宇陀市室生染田',
      '奈良県宇陀市室生無山',
      '奈良県山辺郡',
      '奈良県生駒市',
      '奈良県生駒郡安堵町',
      '奈良県磯城郡川西町下永'
    ],
    'local_code_digits' => 2
  },
  '744' => {
    'addresses' => [
      '奈良県桜井市',
      '奈良県橿原市',
      '奈良県磯城郡田原本町',
      '奈良県高市郡明日香村',
      '奈良県高市郡高取町'
    ],
    'local_code_digits' => 2
  },
  '745' => {
    'addresses' => [
      '奈良県北葛城郡',
      '奈良県吉野郡大淀町今木',
      '奈良県吉野郡大淀町大岩',
      '奈良県吉野郡大淀町鉾立',
      '奈良県大和高田市',
      '奈良県宇陀市',
      '奈良県宇陀郡',
      '奈良県御所市',
      '奈良県生駒郡三郷町',
      '奈良県生駒郡平群町',
      '奈良県生駒郡斑鳩町',
      '奈良県磯城郡三宅町',
      '奈良県磯城郡川西町',
      '奈良県葛城市',
      '奈良県香芝市',
      '奈良県高市郡高取町丹生谷',
      '奈良県高市郡高取町寺崎',
      '奈良県高市郡高取町越智',
      '奈良県高市郡高取町車木'
    ],
    'local_code_digits' => 2
  },
  '746' => {
    'addresses' => [
      '奈良県吉野郡十津川村',
      '奈良県吉野郡吉野町',
      '奈良県吉野郡大淀町中増',
      '奈良県吉野郡大淀町北六田',
      '奈良県吉野郡大淀町北野',
      '奈良県吉野郡大淀町増口',
      '奈良県吉野郡大淀町新野',
      '奈良県吉野郡大淀町比曽',
      '奈良県吉野郡大淀町西増',
      '奈良県吉野郡大淀町馬佐',
      '奈良県吉野郡川上村',
      '奈良県吉野郡東吉野村'
    ],
    'local_code_digits' => 2
  },
  '7468' => {
    'addresses' => [
      '奈良県吉野郡上北山村',
      '奈良県吉野郡下北山村'
    ],
    'local_code_digits' => 1
  },
  '747' => {
    'addresses' => [
      '奈良県五條市',
      '奈良県吉野郡下市町',
      '奈良県吉野郡大淀町',
      '奈良県吉野郡天川村',
      '奈良県吉野郡野迫川村',
      '奈良県吉野郡黒滝村'
    ],
    'local_code_digits' => 2
  },
  '748' => {
    'addresses' => [
      '滋賀県東近江市',
      '滋賀県湖南市',
      '滋賀県甲賀市',
      '滋賀県蒲生郡',
      '滋賀県近江八幡市'
    ],
    'local_code_digits' => 2
  },
  '749' => {
    'addresses' => [
      '滋賀県彦根市',
      '滋賀県愛知郡',
      '滋賀県東近江市上中野町',
      '滋賀県東近江市上山町',
      '滋賀県東近江市上岸本町',
      '滋賀県東近江市下一色町',
      '滋賀県東近江市下中野町',
      '滋賀県東近江市下岸本町',
      '滋賀県東近江市下里町',
      '滋賀県東近江市中一色町',
      '滋賀県東近江市中岸本町',
      '滋賀県東近江市中戸町',
      '滋賀県東近江市中里町',
      '滋賀県東近江市今在家町',
      '滋賀県東近江市僧坊町',
      '滋賀県東近江市勝堂町',
      '滋賀県東近江市北坂町',
      '滋賀県東近江市北清水町',
      '滋賀県東近江市北花沢町',
      '滋賀県東近江市北菩提寺町',
      '滋賀県東近江市南清水町',
      '滋賀県東近江市南花沢町',
      '滋賀県東近江市南菩提寺町',
      '滋賀県東近江市園町',
      '滋賀県東近江市大林町',
      '滋賀県東近江市大沢町',
      '滋賀県東近江市大清水町',
      '滋賀県東近江市大萩町',
      '滋賀県東近江市大覚寺町',
      '滋賀県東近江市妹町',
      '滋賀県東近江市小倉町',
      '滋賀県東近江市小八木町',
      '滋賀県東近江市小池町',
      '滋賀県東近江市小田苅町',
      '滋賀県東近江市市ヶ原町',
      '滋賀県東近江市平尾町',
      '滋賀県東近江市平松町',
      '滋賀県東近江市平柳町',
      '滋賀県東近江市愛東外町',
      '滋賀県東近江市曽根町',
      '滋賀県東近江市梅林町',
      '滋賀県東近江市横溝町',
      '滋賀県東近江市池之尻町',
      '滋賀県東近江市池庄町',
      '滋賀県東近江市清水中町',
      '滋賀県東近江市湯屋町',
      '滋賀県東近江市百済寺本町',
      '滋賀県東近江市百済寺甲町',
      '滋賀県東近江市百済寺町',
      '滋賀県東近江市祇園町',
      '滋賀県東近江市西菩提寺町',
      '滋賀県東近江市読合堂町',
      '滋賀県東近江市長町',
      '滋賀県東近江市青山町',
      '滋賀県東近江市鯰江町',
      '滋賀県犬上郡',
      '滋賀県米原市',
      '滋賀県長浜市'
    ],
    'local_code_digits' => 2
  },
  '75' => {
    'addresses' => [
      '京都府久世郡久御山町',
      '京都府乙訓郡',
      '京都府京都市',
      '京都府八幡市',
      '京都府向日市',
      '京都府長岡京市',
      '大阪府三島郡'
    ],
    'local_code_digits' => 3
  },
  '76' => {
    'addresses' => [
      '富山県中新川郡',
      '富山県富山市',
      '富山県滑川市',
      '石川県かほく市',
      '石川県河北郡',
      '石川県白山市',
      '石川県能美郡',
      '石川県野々市市',
      '石川県金沢市'
    ],
    'local_code_digits' => 3
  },
  '761' => {
    'addresses' => [
      '石川県加賀市',
      '石川県小松市',
      '石川県能美市'
    ],
    'local_code_digits' => 2
  },
  '763' => {
    'addresses' => [
      '富山県南砺市',
      '富山県砺波市'
    ],
    'local_code_digits' => 2
  },
  '765' => {
    'addresses' => [
      '富山県下新川郡',
      '富山県魚津市',
      '富山県黒部市'
    ],
    'local_code_digits' => 2
  },
  '766' => {
    'addresses' => [
      '富山県射水市',
      '富山県小矢部市',
      '富山県氷見市',
      '富山県高岡市'
    ],
    'local_code_digits' => 2
  },
  '767' => {
    'addresses' => [
      '石川県七尾市',
      '石川県羽咋市',
      '石川県羽咋郡',
      '石川県鹿島郡'
    ],
    'local_code_digits' => 2
  },
  '768' => {
    'addresses' => [
      '石川県珠洲市',
      '石川県輪島市',
      '石川県鳳珠郡穴水町',
      '石川県鳳珠郡能登町'
    ],
    'local_code_digits' => 2
  },
  '77' => {
    'addresses' => [
      '京都府京都市伏見区醍醐一ノ切町',
      '京都府京都市伏見区醍醐三ノ切町',
      '京都府京都市伏見区醍醐二ノ切町',
      '滋賀県大津市',
      '滋賀県守山市',
      '滋賀県栗東市',
      '滋賀県草津市',
      '滋賀県野洲市'
    ],
    'local_code_digits' => 3
  },
  '770' => {
    'addresses' => [
      '福井県三方上中郡若狭町',
      '福井県三方上中郡若狭町三方',
      '福井県三方上中郡若狭町上瀬',
      '福井県三方上中郡若狭町上野',
      '福井県三方上中郡若狭町世久見',
      '福井県三方上中郡若狭町中央',
      '福井県三方上中郡若狭町井崎',
      '福井県三方上中郡若狭町佐古',
      '福井県三方上中郡若狭町倉見',
      '福井県三方上中郡若狭町北前川',
      '福井県三方上中郡若狭町南前川',
      '福井県三方上中郡若狭町向笠',
      '福井県三方上中郡若狭町塩坂越',
      '福井県三方上中郡若狭町小川',
      '福井県三方上中郡若狭町岩屋',
      '福井県三方上中郡若狭町島の内',
      '福井県三方上中郡若狭町常神',
      '福井県三方上中郡若狭町成出',
      '福井県三方上中郡若狭町成願寺',
      '福井県三方上中郡若狭町東黒田',
      '福井県三方上中郡若狭町横渡',
      '福井県三方上中郡若狭町気山',
      '福井県三方上中郡若狭町海山',
      '福井県三方上中郡若狭町生倉',
      '福井県三方上中郡若狭町田上',
      '福井県三方上中郡若狭町田井',
      '福井県三方上中郡若狭町田名',
      '福井県三方上中郡若狭町白屋',
      '福井県三方上中郡若狭町相田',
      '福井県三方上中郡若狭町神子',
      '福井県三方上中郡若狭町能登野',
      '福井県三方上中郡若狭町藤井',
      '福井県三方上中郡若狭町遊子',
      '福井県三方上中郡若狭町館川',
      '福井県三方上中郡若狭町鳥浜',
      '福井県三方郡',
      '福井県大飯郡',
      '福井県小浜市',
      '福井県敦賀市'
    ],
    'local_code_digits' => 2
  },
  '771' => {
    'addresses' => [
      '京都府亀岡市',
      '京都府京都市右京区京北室谷町',
      '京都府南丹市',
      '京都府南丹市八木町',
      '京都府船井郡'
    ],
    'local_code_digits' => 2
  },
  '772' => {
    'addresses' => [
      '京都府与謝郡',
      '京都府京丹後市',
      '京都府宮津市'
    ],
    'local_code_digits' => 2
  },
  '773' => {
    'addresses' => [
      '京都府福知山市',
      '京都府綾部市',
      '京都府舞鶴市'
    ],
    'local_code_digits' => 2
  },
  '774' => {
    'addresses' => [
      '京都府久世郡久御山町下津屋',
      '京都府久世郡久御山町佐古',
      '京都府久世郡久御山町佐山',
      '京都府久世郡久御山町市田',
      '京都府久世郡久御山町林',
      '京都府久世郡久御山町栄',
      '京都府久世郡久御山町田井',
      '京都府京田辺市',
      '京都府城陽市',
      '京都府宇治市',
      '京都府木津川市',
      '京都府相楽郡和束町',
      '京都府相楽郡精華町',
      '京都府綴喜郡'
    ],
    'local_code_digits' => 2
  },
  '776' => {
    'addresses' => [
      '福井県あわら市',
      '福井県吉田郡',
      '福井県坂井市',
      '福井県福井市'
    ],
    'local_code_digits' => 2
  },
  '778' => {
    'addresses' => [
      '福井県丹生郡',
      '福井県今立郡',
      '福井県南条郡',
      '福井県越前市',
      '福井県鯖江市'
    ],
    'local_code_digits' => 2
  },
  '779' => {
    'addresses' => [
      '福井県勝山市',
      '福井県大野市'
    ],
    'local_code_digits' => 2
  },
  '78' => {
    'addresses' => [
      '兵庫県加古川市平岡町土山',
      '兵庫県加古郡播磨町上野添',
      '兵庫県加古郡播磨町二子',
      '兵庫県加古郡播磨町北野添',
      '兵庫県加古郡播磨町古宮',
      '兵庫県加古郡播磨町東新島',
      '兵庫県加古郡播磨町東野添',
      '兵庫県加古郡播磨町西野添',
      '兵庫県加古郡播磨町野添',
      '兵庫県加古郡播磨町野添城',
      '兵庫県明石市',
      '兵庫県神戸市',
      '兵庫県西宮市すみれ台',
      '兵庫県西宮市北六甲台',
      '兵庫県西宮市山口町'
    ],
    'local_code_digits' => 3
  },
  '79' => {
    'addresses' => [
      '兵庫県たつの市御津町',
      '兵庫県三田市',
      '兵庫県加古川市',
      '兵庫県加古郡',
      '兵庫県姫路市',
      '兵庫県揖保郡',
      '兵庫県朝来市',
      '兵庫県篠山市',
      '兵庫県養父市',
      '兵庫県高砂市',
      '兵庫県高砂市北浜町北脇',
      '兵庫県高砂市北浜町西浜'
    ],
    'local_code_digits' => 3
  },
  '790' => {
    'addresses' => [
      '兵庫県佐用郡',
      '兵庫県加西市',
      '兵庫県姫路市安富町',
      '兵庫県宍粟市',
      '兵庫県神崎郡'
    ],
    'local_code_digits' => 2
  },
  '791' => {
    'addresses' => [
      '兵庫県たつの市',
      '兵庫県たつの市新宮町角亀',
      '兵庫県相生市',
      '兵庫県赤穂市',
      '兵庫県赤穂郡'
    ],
    'local_code_digits' => 2
  },
  '794' => {
    'addresses' => [
      '兵庫県三木市',
      '兵庫県小野市'
    ],
    'local_code_digits' => 2
  },
  '795' => {
    'addresses' => [
      '兵庫県丹波市',
      '兵庫県加東市',
      '兵庫県多可郡',
      '兵庫県西脇市'
    ],
    'local_code_digits' => 2
  },
  '796' => {
    'addresses' => [
      '兵庫県美方郡',
      '兵庫県美方郡香美町香住区',
      '兵庫県豊岡市'
    ],
    'local_code_digits' => 2
  },
  '797' => {
    'addresses' => [
      '兵庫県宝塚市',
      '兵庫県芦屋市',
      '兵庫県西宮市名塩ガーデン',
      '兵庫県西宮市名塩南台',
      '兵庫県西宮市名塩山荘',
      '兵庫県西宮市名塩新町',
      '兵庫県西宮市名塩茶園町',
      '兵庫県西宮市塩瀬町名塩',
      '兵庫県西宮市塩瀬町生瀬',
      '兵庫県西宮市宝生ヶ丘',
      '兵庫県西宮市東山台',
      '兵庫県西宮市清瀬台',
      '兵庫県西宮市生瀬町',
      '兵庫県西宮市生瀬町東町',
      '兵庫県西宮市生瀬高台',
      '兵庫県西宮市花の峯',
      '兵庫県西宮市青葉台'
    ],
    'local_code_digits' => 2
  },
  '798' => {
    'addresses' => [
      '兵庫県宝塚市仁川うぐいす台',
      '兵庫県宝塚市仁川北',
      '兵庫県宝塚市仁川台',
      '兵庫県宝塚市仁川団地',
      '兵庫県宝塚市仁川宮西町',
      '兵庫県宝塚市仁川旭ガ丘',
      '兵庫県宝塚市仁川月見ガ丘',
      '兵庫県宝塚市仁川高丸',
      '兵庫県宝塚市仁川高台',
      '兵庫県宝塚市新明和町',
      '兵庫県宝塚市駒の町',
      '兵庫県宝塚市鹿塩',
      '兵庫県西宮市'
    ],
    'local_code_digits' => 2
  },
  '799' => {
    'addresses' => [
      '兵庫県南あわじ市',
      '兵庫県洲本市',
      '兵庫県淡路市'
    ],
    'local_code_digits' => 2
  },
  '82' => {
    'addresses' => [
      '広島県安芸郡',
      '広島県広島市',
      '広島県東広島市'
    ],
    'local_code_digits' => 3
  },
  '820' => {
    'addresses' => [
      '山口県光市三輪',
      '山口県光市塩田',
      '山口県光市岩田',
      '山口県光市岩田立野',
      '山口県光市束荷',
      '山口県大島郡',
      '山口県柳井市',
      '山口県熊毛郡'
    ],
    'local_code_digits' => 2
  },
  '823' => {
    'addresses' => [
      '広島県呉市',
      '広島県東広島市黒瀬切田が丘',
      '広島県東広島市黒瀬学園台',
      '広島県東広島市黒瀬春日野',
      '広島県東広島市黒瀬松ケ丘',
      '広島県東広島市黒瀬桜が丘',
      '広島県東広島市黒瀬町',
      '広島県江田島市'
    ],
    'local_code_digits' => 2
  },
  '824' => {
    'addresses' => [
      '広島県三次市',
      '広島県庄原市'
    ],
    'local_code_digits' => 2
  },
  '826' => {
    'addresses' => [
      '広島県安芸高田市',
      '広島県山県郡北広島町',
      '広島県山県郡北広島町中祖',
      '広島県山県郡北広島町南門原',
      '広島県山県郡北広島町土橋',
      '広島県山県郡北広島町大元',
      '広島県山県郡北広島町大利原',
      '広島県山県郡北広島町大暮',
      '広島県山県郡北広島町奥中原',
      '広島県山県郡北広島町奥原',
      '広島県山県郡北広島町宮地',
      '広島県山県郡北広島町小原',
      '広島県山県郡北広島町川小田',
      '広島県山県郡北広島町才乙',
      '広島県山県郡北広島町政所',
      '広島県山県郡北広島町東八幡原',
      '広島県山県郡北広島町橋山',
      '広島県山県郡北広島町溝口',
      '広島県山県郡北広島町移原',
      '広島県山県郡北広島町米沢',
      '広島県山県郡北広島町細見',
      '広島県山県郡北広島町苅屋形',
      '広島県山県郡北広島町草安',
      '広島県山県郡北広島町荒神原',
      '広島県山県郡北広島町西八幡原',
      '広島県山県郡北広島町雲耕',
      '広島県山県郡北広島町高野',
      '広島県山県郡安芸太田町'
    ],
    'local_code_digits' => 2
  },
  '827' => {
    'addresses' => [
      '山口県岩国市',
      '山口県玖珂郡',
      '広島県大竹市'
    ],
    'local_code_digits' => 2
  },
  '829' => {
    'addresses' => [
      '広島県広島市佐伯区杉並台',
      '広島県広島市佐伯区湯来町',
      '広島県廿日市市'
    ],
    'local_code_digits' => 2
  },
  '83' => {
    'addresses' => [
      '山口県下関市',
      '山口県山口市'
    ],
    'local_code_digits' => 3
  },
  '833' => {
    'addresses' => [
      '山口県下松市',
      '山口県光市'
    ],
    'local_code_digits' => 2
  },
  '834' => {
    'addresses' => [
      '山口県周南市'
    ],
    'local_code_digits' => 2
  },
  '835' => {
    'addresses' => [
      '山口県山口市徳地三谷',
      '山口県山口市徳地上村',
      '山口県山口市徳地串',
      '山口県山口市徳地伊賀地',
      '山口県山口市徳地八坂',
      '山口県山口市徳地堀',
      '山口県山口市徳地小古祖',
      '山口県山口市徳地山畑',
      '山口県山口市徳地岸見',
      '山口県山口市徳地島地',
      '山口県山口市徳地引谷',
      '山口県山口市徳地柚木',
      '山口県山口市徳地深谷',
      '山口県山口市徳地船路',
      '山口県山口市徳地藤木',
      '山口県山口市徳地野谷',
      '山口県山口市徳地鯖河内',
      '山口県防府市'
    ],
    'local_code_digits' => 2
  },
  '836' => {
    'addresses' => [
      '山口県宇部市',
      '山口県山口市阿知須',
      '山口県山陽小野田市'
    ],
    'local_code_digits' => 2
  },
  '837' => {
    'addresses' => [
      '山口県美祢市',
      '山口県長門市'
    ],
    'local_code_digits' => 2
  },
  '838' => {
    'addresses' => [
      '山口県萩市'
    ],
    'local_code_digits' => 2
  },
  '8387' => {
    'addresses' => [
      '山口県萩市上小川東分',
      '山口県萩市上小川西分',
      '山口県萩市上田万',
      '山口県萩市下小川',
      '山口県萩市下田万',
      '山口県萩市中小川',
      '山口県萩市弥富上',
      '山口県萩市弥富下',
      '山口県萩市江崎',
      '山口県萩市鈴野川',
      '山口県萩市須佐'
    ],
    'local_code_digits' => 1
  },
  '8388' => {
    'addresses' => [
      '山口県萩市吉部上',
      '山口県萩市吉部下',
      '山口県萩市片俣',
      '山口県萩市高佐上',
      '山口県萩市高佐下',
      '山口県阿武郡'
    ],
    'local_code_digits' => 1
  },
  '8396' => {
    'addresses' => [
      '山口県美祢市美東町'
    ],
    'local_code_digits' => 1
  },
  '84' => {
    'addresses' => [
      '広島県福山市',
      '広島県福山市今津町',
      '広島県福山市南松永町',
      '広島県福山市宮前町',
      '広島県福山市本郷町',
      '広島県福山市東村町',
      '広島県福山市松永町',
      '広島県福山市柳津町',
      '広島県福山市神村町',
      '広島県福山市藤江町',
      '広島県福山市金江町藁江',
      '広島県福山市金江町金見',
      '広島県福山市高西町南',
      '広島県福山市高西町川尻',
      '広島県福山市高西町真田'
    ],
    'local_code_digits' => 3
  },
  '845' => {
    'addresses' => [
      '広島県尾道市因島三庄町',
      '広島県尾道市因島中庄町',
      '広島県尾道市因島原町',
      '広島県尾道市因島土生町',
      '広島県尾道市因島外浦町',
      '広島県尾道市因島大浜町',
      '広島県尾道市因島椋浦町',
      '広島県尾道市因島洲江町',
      '広島県尾道市因島田熊町',
      '広島県尾道市因島重井町',
      '広島県尾道市因島鏡浦町',
      '広島県尾道市瀬戸田町'
    ],
    'local_code_digits' => 2
  },
  '846' => {
    'addresses' => [
      '広島県東広島市安芸津町',
      '広島県竹原市',
      '広島県豊田郡'
    ],
    'local_code_digits' => 2
  },
  '847' => {
    'addresses' => [
      '広島県三原市久井町',
      '広島県三原市大和町',
      '広島県三次市甲奴町',
      '広島県世羅郡',
      '広島県府中市',
      '広島県神石郡',
      '広島県福山市新市町'
    ],
    'local_code_digits' => 2
  },
  '8477' => {
    'addresses' => [
      '広島県庄原市東城町'
    ],
    'local_code_digits' => 1
  },
  '848' => {
    'addresses' => [
      '広島県三原市',
      '広島県尾道市'
    ],
    'local_code_digits' => 2
  },
  '8512' => {
    'addresses' => [
      '島根県隠岐郡隠岐の島町'
    ],
    'local_code_digits' => 1
  },
  '8514' => {
    'addresses' => [
      '島根県隠岐郡'
    ],
    'local_code_digits' => 1
  },
  '852' => {
    'addresses' => [
      '島根県松江市'
    ],
    'local_code_digits' => 2
  },
  '853' => {
    'addresses' => [
      '島根県出雲市'
    ],
    'local_code_digits' => 2
  },
  '854' => {
    'addresses' => [
      '島根県仁多郡',
      '島根県大田市',
      '島根県安来市',
      '島根県雲南市',
      '島根県雲南市吉田町',
      '島根県雲南市掛合町',
      '島根県飯石郡'
    ],
    'local_code_digits' => 2
  },
  '855' => {
    'addresses' => [
      '島根県大田市川合町',
      '島根県大田市湯泉津町',
      '島根県江津市',
      '島根県江津市桜江町',
      '島根県浜田市',
      '島根県邑智郡'
    ],
    'local_code_digits' => 2
  },
  '856' => {
    'addresses' => [
      '島根県益田市',
      '島根県鹿足郡'
    ],
    'local_code_digits' => 2
  },
  '857' => {
    'addresses' => [
      '鳥取県岩美郡',
      '鳥取県鳥取市'
    ],
    'local_code_digits' => 2
  },
  '858' => {
    'addresses' => [
      '鳥取県倉吉市',
      '鳥取県八頭郡',
      '鳥取県東伯郡',
      '鳥取県西伯郡大山町上市',
      '鳥取県西伯郡大山町下市',
      '鳥取県西伯郡大山町下甲',
      '鳥取県西伯郡大山町住吉',
      '鳥取県西伯郡大山町八重',
      '鳥取県西伯郡大山町塩津',
      '鳥取県西伯郡大山町岡',
      '鳥取県西伯郡大山町御崎',
      '鳥取県西伯郡大山町束積',
      '鳥取県西伯郡大山町松河原',
      '鳥取県西伯郡大山町栄田',
      '鳥取県西伯郡大山町樋口',
      '鳥取県西伯郡大山町殿河内',
      '鳥取県西伯郡大山町潮音寺',
      '鳥取県西伯郡大山町田中',
      '鳥取県西伯郡大山町石井垣',
      '鳥取県西伯郡大山町羽田井',
      '鳥取県西伯郡大山町赤坂',
      '鳥取県西伯郡大山町退休寺',
      '鳥取県西伯郡大山町長野',
      '鳥取県西伯郡大山町高橋',
      '鳥取県鳥取市佐治町',
      '鳥取県鳥取市河原町',
      '鳥取県鳥取市用瀬町'
    ],
    'local_code_digits' => 2
  },
  '859' => {
    'addresses' => [
      '鳥取県境港市',
      '鳥取県日野郡',
      '鳥取県米子市',
      '鳥取県西伯郡'
    ],
    'local_code_digits' => 2
  },
  '86' => {
    'addresses' => [
      '岡山県久米郡久米南町',
      '岡山県久米郡美咲町飯岡',
      '岡山県久米郡美咲町高下',
      '岡山県倉敷市',
      '岡山県岡山市',
      '岡山県岡山市南区植松',
      '岡山県岡山市南区箕島',
      '岡山県岡山市南区西畦',
      '岡山県瀬戸内市邑久町北島',
      '岡山県瀬戸内市邑久町向山',
      '岡山県瀬戸内市邑久町大富',
      '岡山県瀬戸内市邑久町福山',
      '岡山県赤磐市',
      '岡山県赤磐市穂崎',
      '岡山県赤磐市馬屋',
      '岡山県都窪郡'
    ],
    'local_code_digits' => 3
  },
  '863' => {
    'addresses' => [
      '岡山県玉野市'
    ],
    'local_code_digits' => 2
  },
  '865' => {
    'addresses' => [
      '岡山県浅口市',
      '岡山県浅口郡',
      '岡山県笠岡市'
    ],
    'local_code_digits' => 2
  },
  '866' => {
    'addresses' => [
      '岡山県井原市',
      '岡山県加賀郡吉備中央町上竹',
      '岡山県加賀郡吉備中央町北',
      '岡山県加賀郡吉備中央町吉川',
      '岡山県加賀郡吉備中央町宮地',
      '岡山県加賀郡吉備中央町岨谷',
      '岡山県加賀郡吉備中央町湯山',
      '岡山県加賀郡吉備中央町田土',
      '岡山県加賀郡吉備中央町竹荘',
      '岡山県加賀郡吉備中央町納地',
      '岡山県加賀郡吉備中央町西',
      '岡山県加賀郡吉備中央町豊野',
      '岡山県加賀郡吉備中央町黒土',
      '岡山県加賀郡吉備中央町黒山',
      '岡山県小田郡',
      '岡山県真庭市上中津井',
      '岡山県真庭市上呰部',
      '岡山県真庭市上水田',
      '岡山県真庭市下中津井',
      '岡山県真庭市下呰部',
      '岡山県真庭市五名',
      '岡山県真庭市宮地',
      '岡山県真庭市山田',
      '岡山県真庭市阿口',
      '岡山県総社市',
      '岡山県高梁市'
    ],
    'local_code_digits' => 2
  },
  '867' => {
    'addresses' => [
      '岡山県久米郡美咲町上口',
      '岡山県久米郡美咲町中',
      '岡山県久米郡美咲町中垪和',
      '岡山県久米郡美咲町北',
      '岡山県久米郡美咲町南',
      '岡山県久米郡美咲町小山',
      '岡山県久米郡美咲町東垪和',
      '岡山県久米郡美咲町栃原',
      '岡山県久米郡美咲町江与味',
      '岡山県久米郡美咲町西',
      '岡山県久米郡美咲町西垪和',
      '岡山県久米郡美咲町西川',
      '岡山県久米郡美咲町西川上',
      '岡山県久米郡美咲町里',
      '岡山県加賀郡吉備中央町',
      '岡山県新見市',
      '岡山県真庭市',
      '岡山県真庭郡',
      '岡山県苫田郡鏡野町大',
      '岡山県苫田郡鏡野町富仲間',
      '岡山県苫田郡鏡野町富東谷',
      '岡山県苫田郡鏡野町富西谷',
      '岡山県苫田郡鏡野町楠'
    ],
    'local_code_digits' => 2
  },
  '868' => {
    'addresses' => [
      '岡山県久米郡美咲町',
      '岡山県勝田郡',
      '岡山県津山市',
      '岡山県美作市',
      '岡山県苫田郡鏡野町',
      '岡山県英田郡'
    ],
    'local_code_digits' => 2
  },
  '869' => {
    'addresses' => [
      '岡山県備前市',
      '岡山県和気郡',
      '岡山県瀬戸内市',
      '岡山県瀬戸内市長船町長船'
    ],
    'local_code_digits' => 2
  },
  '87' => {
    'addresses' => [
      '香川県さぬき市小田',
      '香川県さぬき市志度',
      '香川県さぬき市末',
      '香川県さぬき市鴨庄',
      '香川県さぬき市鴨部',
      '香川県木田郡',
      '香川県綾歌郡綾川町',
      '香川県香川郡',
      '香川県高松市'
    ],
    'local_code_digits' => 3
  },
  '875' => {
    'addresses' => [
      '香川県三豊市',
      '香川県観音寺市'
    ],
    'local_code_digits' => 2
  },
  '877' => {
    'addresses' => [
      '香川県丸亀市',
      '香川県仲多度郡',
      '香川県善通寺市',
      '香川県坂出市',
      '香川県綾歌郡宇多津町'
    ],
    'local_code_digits' => 2
  },
  '879' => {
    'addresses' => [
      '香川県さぬき市',
      '香川県小豆郡',
      '香川県東かがわ市'
    ],
    'local_code_digits' => 2
  },
  '88' => {
    'addresses' => [
      '徳島県名東郡',
      '徳島県名西郡',
      '徳島県徳島市',
      '徳島県板野郡',
      '徳島県阿波市五条',
      '徳島県阿波市吉田',
      '徳島県阿波市土成',
      '徳島県阿波市宮川内',
      '徳島県阿波市成当',
      '徳島県阿波市柿原',
      '徳島県阿波市水田',
      '徳島県阿波市浦池',
      '徳島県阿波市秋月',
      '徳島県阿波市西条',
      '徳島県阿波市郡',
      '徳島県阿波市高尾',
      '徳島県鳴門市',
      '高知県南国市',
      '高知県吾川郡いの町',
      '高知県土佐市',
      '高知県須崎市浦ノ内下中山',
      '高知県須崎市浦ノ内今川内',
      '高知県須崎市浦ノ内出見',
      '高知県須崎市浦ノ内塩間',
      '高知県須崎市浦ノ内灰方',
      '高知県須崎市浦ノ内福良',
      '高知県高知市'
    ],
    'local_code_digits' => 3
  },
  '880' => {
    'addresses' => [
      '高知県四万十市',
      '高知県土佐清水市',
      '高知県宿毛市',
      '高知県幡多郡',
      '高知県幡多郡大月町',
      '高知県高岡郡四万十町'
    ],
    'local_code_digits' => 2
  },
  '883' => {
    'addresses' => [
      '徳島県三好市',
      '徳島県三好郡',
      '徳島県吉野川市',
      '徳島県美馬市',
      '徳島県美馬郡',
      '徳島県阿波市'
    ],
    'local_code_digits' => 2
  },
  '884' => {
    'addresses' => [
      '徳島県海部郡',
      '徳島県那賀郡',
      '徳島県阿南市'
    ],
    'local_code_digits' => 2
  },
  '885' => {
    'addresses' => [
      '徳島県勝浦郡',
      '徳島県小松島市'
    ],
    'local_code_digits' => 2
  },
  '887' => {
    'addresses' => [
      '高知県土佐郡',
      '高知県安芸市',
      '高知県安芸郡北川村',
      '高知県安芸郡奈半利町',
      '高知県安芸郡安田町',
      '高知県安芸郡東洋町',
      '高知県安芸郡田野町',
      '高知県安芸郡芸西村',
      '高知県安芸郡馬路村',
      '高知県室戸市',
      '高知県長岡郡',
      '高知県長岡郡大豊町久寿軒',
      '高知県長岡郡大豊町戸手野',
      '高知県長岡郡大豊町角茂谷',
      '高知県長岡郡大豊町馬瀬',
      '高知県香南市',
      '高知県香美市'
    ],
    'local_code_digits' => 2
  },
  '889' => {
    'addresses' => [
      '高知県吾川郡仁淀川町',
      '高知県須崎市',
      '高知県高岡郡中土佐町',
      '高知県高岡郡佐川町',
      '高知県高岡郡日高村',
      '高知県高岡郡檮原町',
      '高知県高岡郡津野町',
      '高知県高岡郡越知町'
    ],
    'local_code_digits' => 2
  },
  '89' => {
    'addresses' => [
      '愛媛県伊予市',
      '愛媛県伊予郡',
      '愛媛県東温市',
      '愛媛県松山市'
    ],
    'local_code_digits' => 3
  },
  '892' => {
    'addresses' => [
      '愛媛県上浮穴郡',
      '愛媛県喜多郡内子町上川',
      '愛媛県喜多郡内子町上田渡',
      '愛媛県喜多郡内子町中川',
      '愛媛県喜多郡内子町中田渡',
      '愛媛県喜多郡内子町南山',
      '愛媛県喜多郡内子町吉野川',
      '愛媛県喜多郡内子町大平',
      '愛媛県喜多郡内子町寺村',
      '愛媛県喜多郡内子町小田',
      '愛媛県喜多郡内子町日野川',
      '愛媛県喜多郡内子町本川',
      '愛媛県喜多郡内子町立石',
      '愛媛県喜多郡内子町臼杵'
    ],
    'local_code_digits' => 2
  },
  '893' => {
    'addresses' => [
      '愛媛県喜多郡内子町',
      '愛媛県大洲市'
    ],
    'local_code_digits' => 2
  },
  '894' => {
    'addresses' => [
      '愛媛県八幡浜市',
      '愛媛県西予市',
      '愛媛県西予市三瓶町',
      '愛媛県西宇和郡'
    ],
    'local_code_digits' => 2
  },
  '895' => {
    'addresses' => [
      '愛媛県北宇和郡',
      '愛媛県南宇和郡',
      '愛媛県宇和島市'
    ],
    'local_code_digits' => 2
  },
  '896' => {
    'addresses' => [
      '愛媛県四国中央市',
      '香川県観音寺市豊浜町箕浦'
    ],
    'local_code_digits' => 2
  },
  '897' => {
    'addresses' => [
      '愛媛県今治市上浦町',
      '愛媛県今治市伯方町',
      '愛媛県今治市吉海町',
      '愛媛県今治市大三島町',
      '愛媛県今治市宮窪町',
      '愛媛県今治市関前大下',
      '愛媛県今治市関前小大下',
      '愛媛県今治市関前岡村',
      '愛媛県新居浜市',
      '愛媛県西条市',
      '愛媛県越智郡'
    ],
    'local_code_digits' => 2
  },
  '898' => {
    'addresses' => [
      '愛媛県今治市',
      '愛媛県西条市三津屋',
      '愛媛県西条市三津屋南',
      '愛媛県西条市三津屋東',
      '愛媛県西条市三芳',
      '愛媛県西条市上市',
      '愛媛県西条市丹原町',
      '愛媛県西条市今在家',
      '愛媛県西条市円海寺',
      '愛媛県西条市北条',
      '愛媛県西条市吉田',
      '愛媛県西条市周布',
      '愛媛県西条市喜多台',
      '愛媛県西条市国安',
      '愛媛県西条市壬生川',
      '愛媛県西条市大新田',
      '愛媛県西条市大野',
      '愛媛県西条市安用',
      '愛媛県西条市安用出作',
      '愛媛県西条市実報寺',
      '愛媛県西条市宮之内',
      '愛媛県西条市小松町',
      '愛媛県西条市広岡',
      '愛媛県西条市広江',
      '愛媛県西条市新市',
      '愛媛県西条市新町',
      '愛媛県西条市旦之上',
      '愛媛県西条市明理川',
      '愛媛県西条市桑村',
      '愛媛県西条市楠',
      '愛媛県西条市河之内',
      '愛媛県西条市河原津',
      '愛媛県西条市河原津新田',
      '愛媛県西条市玉之江',
      '愛媛県西条市石延',
      '愛媛県西条市石田',
      '愛媛県西条市福成寺',
      '愛媛県西条市高田',
      '愛媛県西条市黒谷'
    ],
    'local_code_digits' => 2
  },
  '92' => {
    'addresses' => [
      '福岡県古賀市',
      '福岡県大野城市',
      '福岡県太宰府市',
      '福岡県春日市',
      '福岡県福岡市',
      '福岡県筑紫郡',
      '福岡県筑紫野市',
      '福岡県糟屋郡',
      '福岡県糸島市'
    ],
    'local_code_digits' => 3
  },
  '920' => {
    'addresses' => [
      '長崎県壱岐市',
      '長崎県対馬市'
    ],
    'local_code_digits' => 2
  },
  '93' => {
    'addresses' => [
      '福岡県中間市',
      '福岡県京都郡苅田町',
      '福岡県北九州市',
      '福岡県遠賀郡'
    ],
    'local_code_digits' => 3
  },
  '930' => {
    'addresses' => [
      '福岡県京都郡みやこ町',
      '福岡県京都郡苅田町上片島',
      '福岡県京都郡苅田町下新津',
      '福岡県京都郡苅田町下片島',
      '福岡県京都郡苅田町与原',
      '福岡県京都郡苅田町二崎',
      '福岡県京都郡苅田町山口',
      '福岡県京都郡苅田町岡崎',
      '福岡県京都郡苅田町新津',
      '福岡県京都郡苅田町法正寺',
      '福岡県京都郡苅田町稲光',
      '福岡県京都郡苅田町葛川',
      '福岡県京都郡苅田町谷',
      '福岡県京都郡苅田町鋤崎',
      '福岡県京都郡苅田町黒添',
      '福岡県築上郡築上町',
      '福岡県行橋市'
    ],
    'local_code_digits' => 2
  },
  '940' => {
    'addresses' => [
      '福岡県宗像市',
      '福岡県福津市'
    ],
    'local_code_digits' => 2
  },
  '942' => {
    'addresses' => [
      '佐賀県三養基郡',
      '佐賀県鳥栖市',
      '福岡県みやま市瀬高町長田',
      '福岡県三井郡',
      '福岡県久留米市',
      '福岡県八女郡広川町広川',
      '福岡県八女郡広川町藤田',
      '福岡県小郡市',
      '福岡県筑後市'
    ],
    'local_code_digits' => 2
  },
  '943' => {
    'addresses' => [
      '福岡県うきは市',
      '福岡県久留米市田主丸町',
      '福岡県八女市',
      '福岡県八女郡広川町'
    ],
    'local_code_digits' => 2
  },
  '944' => {
    'addresses' => [
      '熊本県荒尾市上井手',
      '熊本県荒尾市下井手',
      '福岡県みやま市',
      '福岡県三潴郡',
      '福岡県大川市',
      '福岡県大牟田市',
      '福岡県柳川市',
      '福岡県筑後市下妻',
      '福岡県筑後市富安',
      '福岡県筑後市馬間田'
    ],
    'local_code_digits' => 2
  },
  '946' => {
    'addresses' => [
      '福岡県朝倉市',
      '福岡県朝倉郡'
    ],
    'local_code_digits' => 2
  },
  '947' => {
    'addresses' => [
      '福岡県田川市',
      '福岡県田川郡'
    ],
    'local_code_digits' => 2
  },
  '948' => {
    'addresses' => [
      '福岡県嘉穂郡',
      '福岡県嘉麻市',
      '福岡県飯塚市'
    ],
    'local_code_digits' => 2
  },
  '949' => {
    'addresses' => [
      '福岡県宮若市',
      '福岡県直方市',
      '福岡県鞍手郡鞍手町'
    ],
    'local_code_digits' => 2
  },
  '9496' => {
    'addresses' => [
      '福岡県鞍手郡小竹町',
      '福岡県飯塚市佐與',
      '福岡県飯塚市勢田',
      '福岡県飯塚市口原',
      '福岡県飯塚市鹿毛馬'
    ],
    'local_code_digits' => 1
  },
  '95' => {
    'addresses' => [
      '長崎県西彼杵郡',
      '長崎県長崎市'
    ],
    'local_code_digits' => 3
  },
  '950' => {
    'addresses' => [
      '長崎県平戸市'
    ],
    'local_code_digits' => 2
  },
  '952' => {
    'addresses' => [
      '佐賀県三養基郡上峰町',
      '佐賀県佐賀市',
      '佐賀県多久市',
      '佐賀県小城市',
      '佐賀県杵島郡大町町',
      '佐賀県杵島郡江北町',
      '佐賀県杵島郡白石町',
      '佐賀県神埼市',
      '佐賀県神埼郡'
    ],
    'local_code_digits' => 2
  },
  '954' => {
    'addresses' => [
      '佐賀県嬉野市',
      '佐賀県嬉野市嬉野町',
      '佐賀県杵島郡白石町坂田',
      '佐賀県杵島郡白石町戸ヶ里',
      '佐賀県杵島郡白石町新明',
      '佐賀県杵島郡白石町新開',
      '佐賀県杵島郡白石町深浦',
      '佐賀県杵島郡白石町牛屋',
      '佐賀県杵島郡白石町田野上',
      '佐賀県杵島郡白石町辺田',
      '佐賀県武雄市',
      '佐賀県藤津郡',
      '佐賀県鹿島市'
    ],
    'local_code_digits' => 2
  },
  '955' => {
    'addresses' => [
      '佐賀県伊万里市',
      '佐賀県唐津市',
      '佐賀県東松浦郡',
      '佐賀県西松浦郡',
      '長崎県松浦市福島町',
      '長崎県松浦市鷹島町'
    ],
    'local_code_digits' => 2
  },
  '956' => {
    'addresses' => [
      '長崎県佐世保市',
      '長崎県北松浦郡佐々町',
      '長崎県東彼杵郡',
      '長崎県松浦市'
    ],
    'local_code_digits' => 2
  },
  '957' => {
    'addresses' => [
      '長崎県南島原市',
      '長崎県大村市',
      '長崎県島原市',
      '長崎県東彼杵郡東彼杵町',
      '長崎県諫早市',
      '長崎県雲仙市',
      '長崎県雲仙市千々石町',
      '長崎県雲仙市吾妻町',
      '長崎県雲仙市愛野町'
    ],
    'local_code_digits' => 2
  },
  '959' => {
    'addresses' => [
      '長崎県五島市',
      '長崎県佐世保市宇久町',
      '長崎県北松浦郡',
      '長崎県南松浦郡',
      '長崎県西海市',
      '長崎県長崎市上大野町',
      '長崎県長崎市上黒崎町',
      '長崎県長崎市下大野町',
      '長崎県長崎市下黒崎町',
      '長崎県長崎市新牧野町',
      '長崎県長崎市東出津町',
      '長崎県長崎市永田町',
      '長崎県長崎市池島町',
      '長崎県長崎市神浦上大中尾町',
      '長崎県長崎市神浦上道徳町',
      '長崎県長崎市神浦下大中尾町',
      '長崎県長崎市神浦下道徳町',
      '長崎県長崎市神浦丸尾町',
      '長崎県長崎市神浦北大中尾町',
      '長崎県長崎市神浦口福町',
      '長崎県長崎市神浦向町',
      '長崎県長崎市神浦夏井町',
      '長崎県長崎市神浦扇山町',
      '長崎県長崎市神浦江川町',
      '長崎県長崎市西出津町',
      '長崎県長崎市赤首町'
    ],
    'local_code_digits' => 2
  },
  '96' => {
    'addresses' => [
      '熊本県上益城郡',
      '熊本県合志市',
      '熊本県熊本市',
      '熊本県菊池郡',
      '熊本県阿蘇郡西原村'
    ],
    'local_code_digits' => 3
  },
  '964' => {
    'addresses' => [
      '熊本県上天草市大矢野町',
      '熊本県下益城郡',
      '熊本県八代郡氷川町吉本',
      '熊本県八代郡氷川町高塚',
      '熊本県宇土市',
      '熊本県宇城市',
      '熊本県熊本市南区城南町下宮地',
      '熊本県熊本市南区城南町丹生宮',
      '熊本県熊本市南区城南町今吉野',
      '熊本県熊本市南区城南町六田',
      '熊本県熊本市南区城南町出水',
      '熊本県熊本市南区城南町千町',
      '熊本県熊本市南区城南町坂野',
      '熊本県熊本市南区城南町塚原',
      '熊本県熊本市南区城南町宮地',
      '熊本県熊本市南区城南町島田',
      '熊本県熊本市南区城南町東阿高',
      '熊本県熊本市南区城南町永',
      '熊本県熊本市南区城南町沈目',
      '熊本県熊本市南区城南町碇',
      '熊本県熊本市南区城南町築地',
      '熊本県熊本市南区城南町舞原',
      '熊本県熊本市南区城南町藤山',
      '熊本県熊本市南区城南町赤見',
      '熊本県熊本市南区城南町阿高',
      '熊本県熊本市南区城南町陳内',
      '熊本県熊本市南区城南町隈庄',
      '熊本県熊本市南区城南町高',
      '熊本県熊本市南区城南町鰐瀬'
    ],
    'local_code_digits' => 2
  },
  '965' => {
    'addresses' => [
      '熊本県八代市',
      '熊本県八代郡氷川町'
    ],
    'local_code_digits' => 2
  },
  '966' => {
    'addresses' => [
      '熊本県人吉市',
      '熊本県水俣市',
      '熊本県球磨郡',
      '熊本県葦北郡 '
    ],
    'local_code_digits' => 2
  },
  '967' => {
    'addresses' => [
      '熊本県上益城郡山都町',
      '熊本県阿蘇市',
      '熊本県阿蘇郡南小国町',
      '熊本県阿蘇郡南阿蘇村',
      '熊本県阿蘇郡小国町',
      '熊本県阿蘇郡産山村',
      '熊本県阿蘇郡高森町'
    ],
    'local_code_digits' => 2
  },
  '968' => {
    'addresses' => [
      '熊本県山鹿市',
      '熊本県玉名市',
      '熊本県玉名郡',
      '熊本県玉名郡和水町上十町',
      '熊本県玉名郡和水町上和仁',
      '熊本県玉名郡和水町上板楠',
      '熊本県玉名郡和水町中十町',
      '熊本県玉名郡和水町中和仁',
      '熊本県玉名郡和水町中林',
      '熊本県玉名郡和水町和仁',
      '熊本県玉名郡和水町大田黒',
      '熊本県玉名郡和水町山十町',
      '熊本県玉名郡和水町岩',
      '熊本県玉名郡和水町平野',
      '熊本県玉名郡和水町東吉地',
      '熊本県玉名郡和水町板楠',
      '熊本県玉名郡和水町津田',
      '熊本県玉名郡和水町西吉地',
      '熊本県玉名郡和水町野田',
      '熊本県荒尾市',
      '熊本県菊池市'
    ],
    'local_code_digits' => 2
  },
  '969' => {
    'addresses' => [
      '熊本県上天草市',
      '熊本県天草市',
      '熊本県天草郡'
    ],
    'local_code_digits' => 2
  },
  '97' => {
    'addresses' => [
      '大分県大分市',
      '大分県由布市',
      '大分県豊後大野市犬飼町'
    ],
    'local_code_digits' => 3
  },
  '972' => {
    'addresses' => [
      '大分県佐伯市',
      '大分県津久見市',
      '大分県臼杵市'
    ],
    'local_code_digits' => 2
  },
  '973' => {
    'addresses' => [
      '大分県日田市',
      '大分県玖珠郡'
    ],
    'local_code_digits' => 2
  },
  '974' => {
    'addresses' => [
      '大分県竹田市',
      '大分県臼杵市野津町',
      '大分県豊後大野市',
      '大分県豊後大野市朝地町'
    ],
    'local_code_digits' => 2
  },
  '977' => {
    'addresses' => [
      '大分県別府市',
      '大分県杵築市山香町',
      '大分県由布市湯布院町',
      '大分県速見郡'
    ],
    'local_code_digits' => 2
  },
  '978' => {
    'addresses' => [
      '大分県国東市',
      '大分県国東市国東町',
      '大分県国東市国見町',
      '大分県宇佐市',
      '大分県東国東郡',
      '大分県杵築市',
      '大分県杵築市大田俣水',
      '大分県杵築市大田小野',
      '大分県杵築市大田永松',
      '大分県杵築市大田沓掛',
      '大分県杵築市大田波多方',
      '大分県杵築市大田白木原',
      '大分県杵築市大田石丸',
      '大分県豊後高田市'
    ],
    'local_code_digits' => 2
  },
  '979' => {
    'addresses' => [
      '大分県中津市',
      '福岡県築上郡上毛町',
      '福岡県築上郡吉富町',
      '福岡県豊前市'
    ],
    'local_code_digits' => 2
  },
  '98' => {
    'addresses' => [
      '沖縄県うるま市',
      '沖縄県中頭郡',
      '沖縄県南城市',
      '沖縄県国頭郡宜野座村',
      '沖縄県国頭郡恩納村',
      '沖縄県国頭郡金武町',
      '沖縄県宜野湾市',
      '沖縄県島尻郡',
      '沖縄県沖縄市',
      '沖縄県浦添市',
      '沖縄県糸満市',
      '沖縄県豊見城市',
      '沖縄県那覇市'
    ],
    'local_code_digits' => 3
  },
  '980' => {
    'addresses' => [
      '沖縄県八重山郡',
      '沖縄県名護市',
      '沖縄県国頭郡今帰仁村',
      '沖縄県国頭郡伊江村',
      '沖縄県国頭郡国頭村',
      '沖縄県国頭郡大宜味村',
      '沖縄県国頭郡本部町',
      '沖縄県国頭郡東村',
      '沖縄県宮古島市',
      '沖縄県宮古郡',
      '沖縄県島尻郡伊平屋村',
      '沖縄県島尻郡伊是名村',
      '沖縄県石垣市'
    ],
    'local_code_digits' => 2
  },
  '9802' => {
    'addresses' => [
      '沖縄県島尻郡北大東村',
      '沖縄県島尻郡南大東村'
    ],
    'local_code_digits' => 1
  },
  '982' => {
    'addresses' => [
      '宮崎県児湯郡木城町中之又',
      '宮崎県延岡市',
      '宮崎県日向市',
      '宮崎県東臼杵郡',
      '宮崎県西臼杵郡'
    ],
    'local_code_digits' => 2
  },
  '983' => {
    'addresses' => [
      '宮崎県児湯郡',
      '宮崎県東臼杵郡椎葉村大河内',
      '宮崎県西都市'
    ],
    'local_code_digits' => 2
  },
  '984' => {
    'addresses' => [
      '宮崎県えびの市',
      '宮崎県小林市',
      '宮崎県西諸県郡'
    ],
    'local_code_digits' => 2
  },
  '985' => {
    'addresses' => [
      '宮崎県宮崎市',
      '宮崎県東諸県郡',
      '宮崎県西都市現王島'
    ],
    'local_code_digits' => 2
  },
  '986' => {
    'addresses' => [
      '宮崎県北諸県郡',
      '宮崎県都城市',
      '鹿児島県曽於市'
    ],
    'local_code_digits' => 2
  },
  '987' => {
    'addresses' => [
      '宮崎県串間市',
      '宮崎県日南市'
    ],
    'local_code_digits' => 2
  },
  '99' => {
    'addresses' => [
      '鹿児島県志布志市',
      '鹿児島県日置市',
      '鹿児島県曽於市大隅町',
      '鹿児島県曽於郡',
      '鹿児島県鹿児島市',
      '鹿児島県鹿屋市輝北町'
    ],
    'local_code_digits' => 3
  },
  '9912' => {
    'addresses' => [
      '鹿児島県鹿児島郡十島村'
    ],
    'local_code_digits' => 1
  },
  '9913' => {
    'addresses' => [
      '鹿児島県鹿児島郡三島村'
    ],
    'local_code_digits' => 1
  },
  '993' => {
    'addresses' => [
      '鹿児島県南さつま市',
      '鹿児島県南九州市',
      '鹿児島県南九州市頴娃町',
      '鹿児島県指宿市',
      '鹿児島県枕崎市'
    ],
    'local_code_digits' => 2
  },
  '994' => {
    'addresses' => [
      '鹿児島県垂水市',
      '鹿児島県肝属郡南大隅町',
      '鹿児島県肝属郡東串良町',
      '鹿児島県肝属郡肝付町',
      '鹿児島県肝属郡錦江町',
      '鹿児島県鹿屋市'
    ],
    'local_code_digits' => 2
  },
  '995' => {
    'addresses' => [
      '鹿児島県伊佐市',
      '鹿児島県姶良市',
      '鹿児島県姶良郡',
      '鹿児島県霧島市'
    ],
    'local_code_digits' => 2
  },
  '996' => {
    'addresses' => [
      '鹿児島県いちき串木野市',
      '鹿児島県出水市',
      '鹿児島県出水郡',
      '鹿児島県薩摩川内市',
      '鹿児島県薩摩郡',
      '鹿児島県阿久根市'
    ],
    'local_code_digits' => 2
  },
  '9969' => {
    'addresses' => [
      '鹿児島県薩摩川内市上甑町',
      '鹿児島県薩摩川内市下甑町',
      '鹿児島県薩摩川内市里町',
      '鹿児島県薩摩川内市鹿島町'
    ],
    'local_code_digits' => 1
  },
  '997' => {
    'addresses' => [
      '鹿児島県大島郡',
      '鹿児島県大島郡喜界町',
      '鹿児島県大島郡大和村',
      '鹿児島県大島郡宇検村',
      '鹿児島県大島郡瀬戸内町',
      '鹿児島県大島郡龍郷町',
      '鹿児島県奄美市',
      '鹿児島県熊毛郡',
      '鹿児島県熊毛郡屋久島町',
      '鹿児島県西之表市'
    ],
    'local_code_digits' => 2
  }
};

sub get_areacode2address_map {
    return AREACODE_TO_ADDRESS_MAP;
}

1;
__END__

=encoding utf-8

=head1 NAME

Number::Phone::JP::AreaCode::Data::AreaCode2Address - Provides Area Code to Address Map of Japanese Area Code of Phone

=head1 SYNOPSIS

    package Number::Phone::JP::AreaCode::Data::AreaCode2Address;

    my $areacode2address_map = get_areacode2address_map;

=head1 DESCRIPTION

This module provides area code to address map of Japanese area code of phone.

=head1 FUNCTIONS

=over 4

=item * get_areacode2address_map

Returns area code to address map as hash reference.

=back

=head1 LICENSE

Copyright (C) moznion.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

